@@ -256,12 +256,6 @@ CpuDxeInitialize (
   SyncCacheConfig (&mCpu);
   mIsFlushingGCD = FALSE;
 
-  // If the platform is a MPCore system then install the Configuration Table describing the
-  // secondary core states
-  if (ArmIsMpCore ()) {
-    PublishArmProcessorTable ();
-  }
-
   //
   // Setup a callback for idle events
   //
