@@ -6,8 +6,8 @@
 *
 **/
 
-#ifndef __ARM_GIC_ARCH_LIB_H__
-#define __ARM_GIC_ARCH_LIB_H__
+#ifndef ARM_GIC_ARCH_LIB_H_
+#define ARM_GIC_ARCH_LIB_H_
 
 //
 // GIC definitions
@@ -17,11 +17,10 @@ typedef enum {
   ARM_GIC_ARCH_REVISION_3
 } ARM_GIC_ARCH_REVISION;
 
-
 ARM_GIC_ARCH_REVISION
 EFIAPI
 ArmGicGetSupportedArchRevision (
   VOID
   );
 
-#endif
+#endif // ARM_GIC_ARCH_LIB_H_
