@@ -3,13 +3,9 @@ Ported ELF include files from FreeBSD
 
 Copyright (c) 2009 - 2010, Apple Inc. All rights reserved.<BR>
 Portions Copyright (c) 2011 - 2013, ARM Ltd. All rights reserved.<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+Portion Copyright (c) 2020, Hewlett Packard Enterprise Development LP. All rights reserved.<BR>
+Portions Copyright (c) 2022, Loongson Technology Corporation Limited. All rights reserved.<BR>
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 
 **/
@@ -170,7 +166,6 @@ typedef struct {
 #define EM_H8_300H  47  /* Hitachi H8/300H. */
 #define EM_H8S    48  /* Hitachi H8S. */
 #define EM_H8_500  49  /* Hitachi H8/500. */
-#define EM_IA_64  50  /* Intel IA-64 Processor. */
 #define EM_MIPS_X  51  /* Stanford MIPS-X. */
 #define EM_COLDFIRE  52  /* Motorola ColdFire. */
 #define EM_68HC12  53  /* Motorola M68HC12. */
@@ -185,6 +180,9 @@ typedef struct {
 #define EM_X86_64  62  /* Advanced Micro Devices x86-64 */
 #define  EM_AMD64  EM_X86_64  /* Advanced Micro Devices x86-64 (compat) */
 #define EM_AARCH64  183  /* ARM 64bit Architecture */
+#define EM_RISCV64  243 /* 64bit RISC-V Architecture */
+#define EM_RISCV    244 /* 32bit RISC-V Architecture */
+#define EM_LOONGARCH 258 /* LoongArch Architecture */
 
 /* Non-standard or deprecated. */
 #define EM_486    6  /* Intel i486. */
@@ -775,90 +773,6 @@ typedef struct {
 #define  R_ARM_RPC24    254
 #define  R_ARM_RBASE    255
 
-
-
-/*  Name      Value     Field  Calculation */
-#define  R_IA_64_NONE    0  /* None */
-#define  R_IA_64_IMM14    0x21  /* immediate14  S + A */
-#define  R_IA_64_IMM22    0x22  /* immediate22  S + A */
-#define  R_IA_64_IMM64    0x23  /* immediate64  S + A */
-#define  R_IA_64_DIR32MSB  0x24  /* word32 MSB  S + A */
-#define  R_IA_64_DIR32LSB  0x25  /* word32 LSB  S + A */
-#define  R_IA_64_DIR64MSB  0x26  /* word64 MSB  S + A */
-#define  R_IA_64_DIR64LSB  0x27  /* word64 LSB  S + A */
-#define  R_IA_64_GPREL22    0x2a  /* immediate22  @gprel(S + A) */
-#define  R_IA_64_GPREL64I  0x2b  /* immediate64  @gprel(S + A) */
-#define  R_IA_64_GPREL32MSB  0x2c  /* word32 MSB  @gprel(S + A) */
-#define  R_IA_64_GPREL32LSB  0x2d  /* word32 LSB  @gprel(S + A) */
-#define  R_IA_64_GPREL64MSB  0x2e  /* word64 MSB  @gprel(S + A) */
-#define  R_IA_64_GPREL64LSB  0x2f  /* word64 LSB  @gprel(S + A) */
-#define  R_IA_64_LTOFF22    0x32  /* immediate22  @ltoff(S + A) */
-#define  R_IA_64_LTOFF64I  0x33  /* immediate64  @ltoff(S + A) */
-#define  R_IA_64_PLTOFF22  0x3a  /* immediate22  @pltoff(S + A) */
-#define  R_IA_64_PLTOFF64I  0x3b  /* immediate64  @pltoff(S + A) */
-#define  R_IA_64_PLTOFF64MSB  0x3e  /* word64 MSB  @pltoff(S + A) */
-#define  R_IA_64_PLTOFF64LSB  0x3f  /* word64 LSB  @pltoff(S + A) */
-#define  R_IA_64_FPTR64I    0x43  /* immediate64  @fptr(S + A) */
-#define  R_IA_64_FPTR32MSB  0x44  /* word32 MSB  @fptr(S + A) */
-#define  R_IA_64_FPTR32LSB  0x45  /* word32 LSB  @fptr(S + A) */
-#define  R_IA_64_FPTR64MSB  0x46  /* word64 MSB  @fptr(S + A) */
-#define  R_IA_64_FPTR64LSB  0x47  /* word64 LSB  @fptr(S + A) */
-#define  R_IA_64_PCREL60B  0x48  /* immediate60 form1 S + A - P */
-#define  R_IA_64_PCREL21B  0x49  /* immediate21 form1 S + A - P */
-#define  R_IA_64_PCREL21M  0x4a  /* immediate21 form2 S + A - P */
-#define  R_IA_64_PCREL21F  0x4b  /* immediate21 form3 S + A - P */
-#define  R_IA_64_PCREL32MSB  0x4c  /* word32 MSB  S + A - P */
-#define  R_IA_64_PCREL32LSB  0x4d  /* word32 LSB  S + A - P */
-#define  R_IA_64_PCREL64MSB  0x4e  /* word64 MSB  S + A - P */
-#define  R_IA_64_PCREL64LSB  0x4f  /* word64 LSB  S + A - P */
-#define  R_IA_64_LTOFF_FPTR22  0x52  /* immediate22  @ltoff(@fptr(S + A)) */
-#define  R_IA_64_LTOFF_FPTR64I  0x53  /* immediate64  @ltoff(@fptr(S + A)) */
-#define  R_IA_64_LTOFF_FPTR32MSB  0x54  /* word32 MSB  @ltoff(@fptr(S + A)) */
-#define  R_IA_64_LTOFF_FPTR32LSB  0x55  /* word32 LSB  @ltoff(@fptr(S + A)) */
-#define  R_IA_64_LTOFF_FPTR64MSB  0x56  /* word64 MSB  @ltoff(@fptr(S + A)) */
-#define  R_IA_64_LTOFF_FPTR64LSB  0x57  /* word64 LSB  @ltoff(@fptr(S + A)) */
-#define  R_IA_64_SEGREL32MSB  0x5c  /* word32 MSB  @segrel(S + A) */
-#define  R_IA_64_SEGREL32LSB  0x5d  /* word32 LSB  @segrel(S + A) */
-#define  R_IA_64_SEGREL64MSB  0x5e  /* word64 MSB  @segrel(S + A) */
-#define  R_IA_64_SEGREL64LSB  0x5f  /* word64 LSB  @segrel(S + A) */
-#define  R_IA_64_SECREL32MSB  0x64  /* word32 MSB  @secrel(S + A) */
-#define  R_IA_64_SECREL32LSB  0x65  /* word32 LSB  @secrel(S + A) */
-#define  R_IA_64_SECREL64MSB  0x66  /* word64 MSB  @secrel(S + A) */
-#define  R_IA_64_SECREL64LSB  0x67  /* word64 LSB  @secrel(S + A) */
-#define  R_IA_64_REL32MSB  0x6c  /* word32 MSB  BD + A */
-#define  R_IA_64_REL32LSB  0x6d  /* word32 LSB  BD + A */
-#define  R_IA_64_REL64MSB  0x6e  /* word64 MSB  BD + A */
-#define  R_IA_64_REL64LSB  0x6f  /* word64 LSB  BD + A */
-#define  R_IA_64_LTV32MSB  0x74  /* word32 MSB  S + A */
-#define  R_IA_64_LTV32LSB  0x75  /* word32 LSB  S + A */
-#define  R_IA_64_LTV64MSB  0x76  /* word64 MSB  S + A */
-#define  R_IA_64_LTV64LSB  0x77  /* word64 LSB  S + A */
-#define  R_IA_64_PCREL21BI  0x79  /* immediate21 form1 S + A - P */
-#define  R_IA_64_PCREL22    0x7a  /* immediate22  S + A - P */
-#define  R_IA_64_PCREL64I  0x7b  /* immediate64  S + A - P */
-#define  R_IA_64_IPLTMSB    0x80  /* function descriptor MSB special */
-#define  R_IA_64_IPLTLSB    0x81  /* function descriptor LSB speciaal */
-#define  R_IA_64_SUB    0x85  /* immediate64  A - S */
-#define  R_IA_64_LTOFF22X  0x86  /* immediate22  special */
-#define  R_IA_64_LDXMOV    0x87  /* immediate22  special */
-#define  R_IA_64_TPREL14    0x91  /* imm14  @tprel(S + A) */
-#define  R_IA_64_TPREL22    0x92  /* imm22  @tprel(S + A) */
-#define  R_IA_64_TPREL64I  0x93  /* imm64  @tprel(S + A) */
-#define  R_IA_64_TPREL64MSB  0x96  /* word64 MSB  @tprel(S + A) */
-#define  R_IA_64_TPREL64LSB  0x97  /* word64 LSB  @tprel(S + A) */
-#define  R_IA_64_LTOFF_TPREL22  0x9a  /* imm22  @ltoff(@tprel(S+A)) */
-#define  R_IA_64_DTPMOD64MSB  0xa6  /* word64 MSB  @dtpmod(S + A) */
-#define  R_IA_64_DTPMOD64LSB  0xa7  /* word64 LSB  @dtpmod(S + A) */
-#define  R_IA_64_LTOFF_DTPMOD22  0xaa  /* imm22  @ltoff(@dtpmod(S+A)) */
-#define  R_IA_64_DTPREL14  0xb1  /* imm14  @dtprel(S + A) */
-#define  R_IA_64_DTPREL22  0xb2  /* imm22  @dtprel(S + A) */
-#define  R_IA_64_DTPREL64I  0xb3  /* imm64  @dtprel(S + A) */
-#define  R_IA_64_DTPREL32MSB  0xb4  /* word32 MSB  @dtprel(S + A) */
-#define  R_IA_64_DTPREL32LSB  0xb5  /* word32 LSB  @dtprel(S + A) */
-#define  R_IA_64_DTPREL64MSB  0xb6  /* word64 MSB  @dtprel(S + A) */
-#define  R_IA_64_DTPREL64LSB  0xb7  /* word64 LSB  @dtprel(S + A) */
-#define  R_IA_64_LTOFF_DTPREL22  0xba  /* imm22  @ltoff(@dtprel(S+A)) */
-
 #define  R_PPC_NONE    0  /* No relocation. */
 #define  R_PPC_ADDR32    1
 #define  R_PPC_ADDR24    2
@@ -1070,5 +984,156 @@ typedef struct {
 #define  R_X86_64_GOTPCRELX  41  /* Load from 32 bit signed pc relative offset to GOT entry without REX prefix, relaxable. */
 #define  R_X86_64_REX_GOTPCRELX  42  /* Load from 32 bit signed pc relative offset to GOT entry with REX prefix, relaxable. */
 
+/*
+ * RISC-V relocation types
+ */
 
+/* Relocation types used by the dynamic linker */
+#define R_RISCV_NONE        0
+#define R_RISCV_32          1
+#define R_RISCV_64          2
+#define R_RISCV_RELATIVE    3
+#define R_RISCV_COPY        4
+#define R_RISCV_JUMP_SLOT   5
+#define R_RISCV_TLS_DTPMOD32    6
+#define R_RISCV_TLS_DTPMOD64    7
+#define R_RISCV_TLS_DTPREL32    8
+#define R_RISCV_TLS_DTPREL64    9
+#define R_RISCV_TLS_TPREL32     10
+#define R_RISCV_TLS_TPREL64     11
+
+/* Relocation types not used by the dynamic linker */
+#define R_RISCV_BRANCH      16
+#define R_RISCV_JAL         17
+#define R_RISCV_CALL        18
+#define R_RISCV_CALL_PLT    19
+#define R_RISCV_GOT_HI20    20
+#define R_RISCV_TLS_GOT_HI20    21
+#define R_RISCV_TLS_GD_HI20     22
+#define R_RISCV_PCREL_HI20      23
+#define R_RISCV_PCREL_LO12_I    24
+#define R_RISCV_PCREL_LO12_S    25
+#define R_RISCV_HI20            26
+#define R_RISCV_LO12_I          27
+#define R_RISCV_LO12_S          28
+#define R_RISCV_TPREL_HI20      29
+#define R_RISCV_TPREL_LO12_I    30
+#define R_RISCV_TPREL_LO12_S    31
+#define R_RISCV_TPREL_ADD       32
+#define R_RISCV_ADD8            33
+#define R_RISCV_ADD16           34
+#define R_RISCV_ADD32           35
+#define R_RISCV_ADD64           36
+#define R_RISCV_SUB8            37
+#define R_RISCV_SUB16           38
+#define R_RISCV_SUB32           39
+#define R_RISCV_SUB64           40
+#define R_RISCV_GNU_VTINHERIT   41
+#define R_RISCV_GNU_VTENTRY     42
+#define R_RISCV_ALIGN           43
+#define R_RISCV_RVC_BRANCH      44
+#define R_RISCV_RVC_JUMP        45
+#define R_RISCV_RVC_LUI         46
+#define R_RISCV_GPREL_I         47
+#define R_RISCV_GPREL_S         48
+#define R_RISCV_TPREL_I         49
+#define R_RISCV_TPREL_S         50
+#define R_RISCV_RELAX           51
+#define R_RISCV_SUB6            52
+#define R_RISCV_SET6            53
+#define R_RISCV_SET8            54
+#define R_RISCV_SET16           55
+#define R_RISCV_SET32           56
+
+/*
+ * LoongArch relocation types
+ */
+#define R_LARCH_NONE                       0
+#define R_LARCH_32                         1
+#define R_LARCH_64                         2
+#define R_LARCH_RELATIVE                   3
+#define R_LARCH_COPY                       4
+#define R_LARCH_JUMP_SLOT                  5
+#define R_LARCH_TLS_DTPMOD32               6
+#define R_LARCH_TLS_DTPMOD64               7
+#define R_LARCH_TLS_DTPREL32               8
+#define R_LARCH_TLS_DTPREL64               9
+#define R_LARCH_TLS_TPREL32                10
+#define R_LARCH_TLS_TPREL64                11
+#define R_LARCH_IRELATIVE                  12
+#define R_LARCH_MARK_LA                    20
+#define R_LARCH_MARK_PCREL                 21
+#define R_LARCH_SOP_PUSH_PCREL             22
+#define R_LARCH_SOP_PUSH_ABSOLUTE          23
+#define R_LARCH_SOP_PUSH_DUP               24
+#define R_LARCH_SOP_PUSH_GPREL             25
+#define R_LARCH_SOP_PUSH_TLS_TPREL         26
+#define R_LARCH_SOP_PUSH_TLS_GOT           27
+#define R_LARCH_SOP_PUSH_TLS_GD            28
+#define R_LARCH_SOP_PUSH_PLT_PCREL         29
+#define R_LARCH_SOP_ASSERT                 30
+#define R_LARCH_SOP_NOT                    31
+#define R_LARCH_SOP_SUB                    32
+#define R_LARCH_SOP_SL                     33
+#define R_LARCH_SOP_SR                     34
+#define R_LARCH_SOP_ADD                    35
+#define R_LARCH_SOP_AND                    36
+#define R_LARCH_SOP_IF_ELSE                37
+#define R_LARCH_SOP_POP_32_S_10_5          38
+#define R_LARCH_SOP_POP_32_U_10_12         39
+#define R_LARCH_SOP_POP_32_S_10_12         40
+#define R_LARCH_SOP_POP_32_S_10_16         41
+#define R_LARCH_SOP_POP_32_S_10_16_S2      42
+#define R_LARCH_SOP_POP_32_S_5_20          43
+#define R_LARCH_SOP_POP_32_S_0_5_10_16_S2  44
+#define R_LARCH_SOP_POP_32_S_0_10_10_16_S2 45
+#define R_LARCH_SOP_POP_32_U               46
+#define R_LARCH_ADD8                       47
+#define R_LARCH_ADD16                      48
+#define R_LARCH_ADD24                      49
+#define R_LARCH_ADD32                      50
+#define R_LARCH_ADD64                      51
+#define R_LARCH_SUB8                       52
+#define R_LARCH_SUB16                      53
+#define R_LARCH_SUB24                      54
+#define R_LARCH_SUB32                      55
+#define R_LARCH_SUB64                      56
+#define R_LARCH_GNU_VTINHERIT              57
+#define R_LARCH_GNU_VTENTRY                58
+#define R_LARCH_B16                        64
+#define R_LARCH_B21                        65
+#define R_LARCH_B26                        66
+#define R_LARCH_ABS_HI20                   67
+#define R_LARCH_ABS_LO12                   68
+#define R_LARCH_ABS64_LO20                 69
+#define R_LARCH_ABS64_HI12                 70
+#define R_LARCH_PCALA_HI20                 71
+#define R_LARCH_PCALA_LO12                 72
+#define R_LARCH_PCALA64_LO20               73
+#define R_LARCH_PCALA64_HI12               74
+#define R_LARCH_GOT_PC_HI20                75
+#define R_LARCH_GOT_PC_LO12                76
+#define R_LARCH_GOT64_PC_LO20              77
+#define R_LARCH_GOT64_PC_HI12              78
+#define R_LARCH_GOT64_HI20                 79
+#define R_LARCH_GOT64_LO12                 80
+#define R_LARCH_GOT64_LO20                 81
+#define R_LARCH_GOT64_HI12                 82
+#define R_LARCH_TLS_LE_HI20                83
+#define R_LARCH_TLS_LE_LO12                84
+#define R_LARCH_TLS_LE64_LO20              85
+#define R_LARCH_TLS_LE64_HI12              86
+#define R_LARCH_TLS_IE_PC_HI20             87
+#define R_LARCH_TLS_IE_PC_LO12             88
+#define R_LARCH_TLS_IE64_PC_LO20           89
+#define R_LARCH_TLS_IE64_PC_HI12           90
+#define R_LARCH_TLS_IE64_HI20              91
+#define R_LARCH_TLS_IE64_LO12              92
+#define R_LARCH_TLS_IE64_LO20              93
+#define R_LARCH_TLS_IE64_HI12              94
+#define R_LARCH_TLS_LD_PC_HI20             95
+#define R_LARCH_TLS_LD64_HI20              96
+#define R_LARCH_TLS_GD_PC_HI20             97
+#define R_LARCH_TLS_GD64_HI20              98
+#define R_LARCH_RELAX                      99
 #endif /* !_SYS_ELF_COMMON_H_ */
