@@ -4,14 +4,7 @@
 Copyright (c) 2006 - 2018, Intel Corporation. All rights reserved.<BR>
 Copyright (c) 2018, Linaro Ltd. All rights reserved.<BR>
 
-This program and the accompanying materials
-are licensed and made available under the terms and conditions
-of the BSD License which accompanies this distribution.  The
-full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -20,7 +13,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 //
 // RAM Keyboard Driver Binding Protocol Instance
 //
-EFI_DRIVER_BINDING_PROTOCOL gVirtualKeyboardDriverBinding = {
+EFI_DRIVER_BINDING_PROTOCOL  gVirtualKeyboardDriverBinding = {
   VirtualKeyboardDriverBindingSupported,
   VirtualKeyboardDriverBindingStart,
   VirtualKeyboardDriverBindingStop,
@@ -52,13 +45,13 @@ VirtualKeyboardDriverBindingSupported (
   IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   )
 {
-  EFI_STATUS                      Status;
-  PLATFORM_VIRTUAL_KBD_PROTOCOL   *PlatformVirtual;
+  EFI_STATUS                     Status;
+  PLATFORM_VIRTUAL_KBD_PROTOCOL  *PlatformVirtual;
 
   Status = gBS->OpenProtocol (
                   Controller,
                   &gPlatformVirtualKeyboardProtocolGuid,
-                  (VOID **) &PlatformVirtual,
+                  (VOID **)&PlatformVirtual,
                   This->DriverBindingHandle,
                   Controller,
                   EFI_OPEN_PROTOCOL_BY_DRIVER
@@ -66,6 +59,7 @@ VirtualKeyboardDriverBindingSupported (
   if (EFI_ERROR (Status)) {
     return Status;
   }
+
   gBS->CloseProtocol (
          Controller,
          &gPlatformVirtualKeyboardProtocolGuid,
@@ -95,14 +89,14 @@ VirtualKeyboardDriverBindingStart (
   IN EFI_DEVICE_PATH_PROTOCOL     *RemainingDevicePath
   )
 {
-  EFI_STATUS                                Status;
-  VIRTUAL_KEYBOARD_DEV                      *VirtualKeyboardPrivate;
-  PLATFORM_VIRTUAL_KBD_PROTOCOL             *PlatformVirtual;
+  EFI_STATUS                     Status;
+  VIRTUAL_KEYBOARD_DEV           *VirtualKeyboardPrivate;
+  PLATFORM_VIRTUAL_KBD_PROTOCOL  *PlatformVirtual;
 
   Status = gBS->OpenProtocol (
                   Controller,
                   &gPlatformVirtualKeyboardProtocolGuid,
-                  (VOID **) &PlatformVirtual,
+                  (VOID **)&PlatformVirtual,
                   This->DriverBindingHandle,
                   Controller,
                   EFI_OPEN_PROTOCOL_BY_DRIVER
@@ -114,7 +108,7 @@ VirtualKeyboardDriverBindingStart (
   //
   // Allocate the private device structure
   //
-  VirtualKeyboardPrivate = (VIRTUAL_KEYBOARD_DEV *) AllocateZeroPool (sizeof (VIRTUAL_KEYBOARD_DEV));
+  VirtualKeyboardPrivate = (VIRTUAL_KEYBOARD_DEV *)AllocateZeroPool (sizeof (VIRTUAL_KEYBOARD_DEV));
   if (VirtualKeyboardPrivate == NULL) {
     Status = EFI_OUT_OF_RESOURCES;
     goto Done;
@@ -123,20 +117,20 @@ VirtualKeyboardDriverBindingStart (
   //
   // Initialize the private device structure
   //
-  VirtualKeyboardPrivate->Signature                  = VIRTUAL_KEYBOARD_DEV_SIGNATURE;
-  VirtualKeyboardPrivate->Handle                     = Controller;
-  VirtualKeyboardPrivate->PlatformVirtual            = PlatformVirtual;
-  VirtualKeyboardPrivate->Queue.Front                = 0;
-  VirtualKeyboardPrivate->Queue.Rear                 = 0;
-  VirtualKeyboardPrivate->QueueForNotify.Front       = 0;
-  VirtualKeyboardPrivate->QueueForNotify.Rear        = 0;
+  VirtualKeyboardPrivate->Signature            = VIRTUAL_KEYBOARD_DEV_SIGNATURE;
+  VirtualKeyboardPrivate->Handle               = Controller;
+  VirtualKeyboardPrivate->PlatformVirtual      = PlatformVirtual;
+  VirtualKeyboardPrivate->Queue.Front          = 0;
+  VirtualKeyboardPrivate->Queue.Rear           = 0;
+  VirtualKeyboardPrivate->QueueForNotify.Front = 0;
+  VirtualKeyboardPrivate->QueueForNotify.Rear  = 0;
 
   VirtualKeyboardPrivate->SimpleTextIn.Reset         = VirtualKeyboardReset;
   VirtualKeyboardPrivate->SimpleTextIn.ReadKeyStroke = VirtualKeyboardReadKeyStroke;
 
-  VirtualKeyboardPrivate->SimpleTextInputEx.Reset               = VirtualKeyboardResetEx;
-  VirtualKeyboardPrivate->SimpleTextInputEx.ReadKeyStrokeEx     = VirtualKeyboardReadKeyStrokeEx;
-  VirtualKeyboardPrivate->SimpleTextInputEx.SetState            = VirtualKeyboardSetState;
+  VirtualKeyboardPrivate->SimpleTextInputEx.Reset           = VirtualKeyboardResetEx;
+  VirtualKeyboardPrivate->SimpleTextInputEx.ReadKeyStrokeEx = VirtualKeyboardReadKeyStrokeEx;
+  VirtualKeyboardPrivate->SimpleTextInputEx.SetState        = VirtualKeyboardSetState;
 
   VirtualKeyboardPrivate->SimpleTextInputEx.RegisterKeyNotify   = VirtualKeyboardRegisterKeyNotify;
   VirtualKeyboardPrivate->SimpleTextInputEx.UnregisterKeyNotify = VirtualKeyboardUnregisterKeyNotify;
@@ -169,6 +163,7 @@ VirtualKeyboardDriverBindingStart (
     (VirtualKeyboardPrivate->SimpleTextIn).WaitForKey = NULL;
     goto Done;
   }
+
   Status = gBS->CreateEvent (
                   EVT_NOTIFY_WAIT,
                   TPL_NOTIFY,
@@ -222,13 +217,14 @@ VirtualKeyboardDriverBindingStart (
   // Reset the keyboard device
   //
   Status = VirtualKeyboardPrivate->SimpleTextInputEx.Reset (
-                                     &VirtualKeyboardPrivate->SimpleTextInputEx,
-                                     FALSE
-                                     );
+                                                       &VirtualKeyboardPrivate->SimpleTextInputEx,
+                                                       FALSE
+                                                       );
   if (EFI_ERROR (Status)) {
     DEBUG ((DEBUG_ERROR, "[KBD]Reset Failed. Status - %r\n", Status));
     goto Done;
   }
+
   //
   // Install protocol interfaces for the keyboard device.
   //
@@ -263,6 +259,7 @@ Done:
       if (VirtualKeyboardPrivate->TimerEvent != NULL) {
         gBS->CloseEvent (VirtualKeyboardPrivate->TimerEvent);
       }
+
       FreePool (VirtualKeyboardPrivate);
     }
   }
@@ -304,7 +301,6 @@ VirtualKeyboardDriverBindingStop (
   return EFI_SUCCESS;
 }
 
-
 /**
   Enqueue the key.
 
@@ -317,8 +313,8 @@ VirtualKeyboardDriverBindingStop (
 **/
 EFI_STATUS
 Enqueue (
-  IN SIMPLE_QUEUE         *Queue,
-  IN EFI_KEY_DATA         *KeyData
+  IN SIMPLE_QUEUE  *Queue,
+  IN EFI_KEY_DATA  *KeyData
   )
 {
   if ((Queue->Rear + 1) % QUEUE_MAX_COUNT == Queue->Front) {
@@ -343,8 +339,8 @@ Enqueue (
 **/
 EFI_STATUS
 Dequeue (
-  IN SIMPLE_QUEUE         *Queue,
-  IN EFI_KEY_DATA         *KeyData
+  IN SIMPLE_QUEUE  *Queue,
+  IN EFI_KEY_DATA  *KeyData
   )
 {
   if (Queue->Front == Queue->Rear) {
@@ -352,7 +348,7 @@ Dequeue (
   }
 
   CopyMem (KeyData, &Queue->Buffer[Queue->Front], sizeof (EFI_KEY_DATA));
-  Queue->Front  = (Queue->Front + 1) % QUEUE_MAX_COUNT;
+  Queue->Front = (Queue->Front + 1) % QUEUE_MAX_COUNT;
 
   return EFI_SUCCESS;
 }
@@ -368,7 +364,7 @@ Dequeue (
 **/
 EFI_STATUS
 CheckQueue (
-  IN SIMPLE_QUEUE         *Queue
+  IN SIMPLE_QUEUE  *Queue
   )
 {
   if (Queue->Front == Queue->Rear) {
@@ -393,7 +389,7 @@ VirtualKeyboardCheckForKey (
   IN  EFI_SIMPLE_TEXT_INPUT_PROTOCOL  *This
   )
 {
-  VIRTUAL_KEYBOARD_DEV     *VirtualKeyboardPrivate;
+  VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate;
 
   VirtualKeyboardPrivate = VIRTUAL_KEYBOARD_DEV_FROM_THIS (This);
 
@@ -411,14 +407,15 @@ VirtualKeyboardCheckForKey (
 **/
 EFI_STATUS
 VirtualKeyboardFreeNotifyList (
-  IN OUT LIST_ENTRY           *ListHead
+  IN OUT LIST_ENTRY  *ListHead
   )
 {
-  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *NotifyNode;
+  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY  *NotifyNode;
 
   if (ListHead == NULL) {
     return EFI_INVALID_PARAMETER;
   }
+
   while (!IsListEmpty (ListHead)) {
     NotifyNode = CR (
                    ListHead->ForwardLink,
@@ -444,7 +441,7 @@ VirtualKeyboardFreeNotifyList (
                               pressed.
 
   @retval TRUE                Key be pressed matches a registered key.
-  @retval FLASE               Match failed.
+  @retval FALSE               Match failed.
 
 **/
 BOOLEAN
@@ -457,7 +454,8 @@ IsKeyRegistered (
   ASSERT (RegsiteredData != NULL && InputData != NULL);
 
   if ((RegsiteredData->Key.ScanCode    != InputData->Key.ScanCode) ||
-      (RegsiteredData->Key.UnicodeChar != InputData->Key.UnicodeChar)) {
+      (RegsiteredData->Key.UnicodeChar != InputData->Key.UnicodeChar))
+  {
     return FALSE;
   }
 
@@ -466,16 +464,18 @@ IsKeyRegistered (
   // these state could be ignored.
   //
   if ((RegsiteredData->KeyState.KeyShiftState != 0) &&
-      (RegsiteredData->KeyState.KeyShiftState != InputData->KeyState.KeyShiftState)) {
+      (RegsiteredData->KeyState.KeyShiftState != InputData->KeyState.KeyShiftState))
+  {
     return FALSE;
   }
+
   if ((RegsiteredData->KeyState.KeyToggleState != 0) &&
-      (RegsiteredData->KeyState.KeyToggleState != InputData->KeyState.KeyToggleState)) {
+      (RegsiteredData->KeyState.KeyToggleState != InputData->KeyState.KeyToggleState))
+  {
     return FALSE;
   }
 
   return TRUE;
-
 }
 
 /**
@@ -483,14 +483,14 @@ IsKeyRegistered (
   Signal the event if there is key available
 
   @param Event    the event object
-  @param Context  waitting context
+  @param Context  waiting context
 
 **/
 VOID
 EFIAPI
 VirtualKeyboardWaitForKey (
-  IN  EFI_EVENT               Event,
-  IN  VOID                    *Context
+  IN  EFI_EVENT  Event,
+  IN  VOID       *Context
   )
 {
   //
@@ -526,21 +526,21 @@ VirtualKeyboardWaitForKey (
 VOID
 EFIAPI
 VirtualKeyboardWaitForKeyEx (
-  IN  EFI_EVENT               Event,
-  IN  VOID                    *Context
+  IN  EFI_EVENT  Event,
+  IN  VOID       *Context
   )
 
 {
-  VIRTUAL_KEYBOARD_DEV                     *VirtualKeyboardPrivate;
+  VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate;
 
   VirtualKeyboardPrivate = TEXT_INPUT_EX_VIRTUAL_KEYBOARD_DEV_FROM_THIS (Context);
   VirtualKeyboardWaitForKey (Event, &VirtualKeyboardPrivate->SimpleTextIn);
-
 }
 
 //
 // EFI Simple Text In Protocol Functions
 //
+
 /**
   Reset the Keyboard and do BAT test for it, if (ExtendedVerification == TRUE)
   then do some extra keyboard validations.
@@ -560,9 +560,9 @@ VirtualKeyboardReset (
   IN  BOOLEAN                         ExtendedVerification
   )
 {
-  VIRTUAL_KEYBOARD_DEV *VirtualKeyboardPrivate;
-  EFI_STATUS           Status;
-  EFI_TPL              OldTpl;
+  VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate;
+  EFI_STATUS            Status;
+  EFI_TPL               OldTpl;
 
   VirtualKeyboardPrivate = VIRTUAL_KEYBOARD_DEV_FROM_THIS (This);
 
@@ -572,7 +572,8 @@ VirtualKeyboardReset (
   OldTpl = gBS->RaiseTPL (TPL_NOTIFY);
 
   if (VirtualKeyboardPrivate->PlatformVirtual &&
-      VirtualKeyboardPrivate->PlatformVirtual->Reset) {
+      VirtualKeyboardPrivate->PlatformVirtual->Reset)
+  {
     Status = VirtualKeyboardPrivate->PlatformVirtual->Reset ();
   } else {
     Status = EFI_INVALID_PARAMETER;
@@ -587,7 +588,7 @@ VirtualKeyboardReset (
 }
 
 /**
-  Reset the input device and optionaly run diagnostics
+  Reset the input device and optionally run diagnostics
 
   @param  This                  Protocol instance pointer.
   @param  ExtendedVerification  Driver may perform diagnostics on reset.
@@ -604,16 +605,16 @@ VirtualKeyboardResetEx (
   IN BOOLEAN                            ExtendedVerification
   )
 {
-  VIRTUAL_KEYBOARD_DEV                  *VirtualKeyboardPrivate;
-  EFI_STATUS                            Status;
-  EFI_TPL                               OldTpl;
+  VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate;
+  EFI_STATUS            Status;
+  EFI_TPL               OldTpl;
 
   VirtualKeyboardPrivate = TEXT_INPUT_EX_VIRTUAL_KEYBOARD_DEV_FROM_THIS (This);
 
   Status = VirtualKeyboardPrivate->SimpleTextIn.Reset (
-                                     &VirtualKeyboardPrivate->SimpleTextIn,
-                                     ExtendedVerification
-                                     );
+                                                  &VirtualKeyboardPrivate->SimpleTextIn,
+                                                  ExtendedVerification
+                                                  );
   if (EFI_ERROR (Status)) {
     return EFI_DEVICE_ERROR;
   }
@@ -623,12 +624,11 @@ VirtualKeyboardResetEx (
   gBS->RestoreTPL (OldTpl);
 
   return EFI_SUCCESS;
-
 }
 
 /**
   Reads the next keystroke from the input device. The WaitForKey Event can
-  be used to test for existance of a keystroke via WaitForEvent () call.
+  be used to test for existence of a keystroke via WaitForEvent () call.
 
   @param  VirtualKeyboardPrivate   Virtualkeyboard driver private structure.
   @param  KeyData                  A pointer to a buffer that is filled in
@@ -636,7 +636,7 @@ VirtualKeyboardResetEx (
                                    that was pressed.
 
   @retval EFI_SUCCESS              The keystroke information was returned.
-  @retval EFI_NOT_READY            There was no keystroke data availiable.
+  @retval EFI_NOT_READY            There was no keystroke data available.
   @retval EFI_DEVICE_ERROR         The keystroke information was not returned
                                    due to hardware errors.
   @retval EFI_INVALID_PARAMETER    KeyData is NULL.
@@ -645,11 +645,12 @@ VirtualKeyboardResetEx (
 EFI_STATUS
 KeyboardReadKeyStrokeWorker (
   IN VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate,
-  OUT EFI_KEY_DATA      *KeyData
+  OUT EFI_KEY_DATA         *KeyData
   )
 {
-  EFI_STATUS                            Status;
-  EFI_TPL                               OldTpl;
+  EFI_STATUS  Status;
+  EFI_TPL     OldTpl;
+
   if (KeyData == NULL) {
     return EFI_INVALID_PARAMETER;
   }
@@ -707,9 +708,9 @@ VirtualKeyboardReadKeyStroke (
   OUT EFI_INPUT_KEY                   *Key
   )
 {
-  VIRTUAL_KEYBOARD_DEV     *VirtualKeyboardPrivate;
-  EFI_STATUS               Status;
-  EFI_KEY_DATA             KeyData;
+  VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate;
+  EFI_STATUS            Status;
+  EFI_KEY_DATA          KeyData;
 
   VirtualKeyboardPrivate = VIRTUAL_KEYBOARD_DEV_FROM_THIS (This);
 
@@ -722,12 +723,14 @@ VirtualKeyboardReadKeyStroke (
   // Convert the Ctrl+[a-z] to Ctrl+[1-26]
   //
   if ((KeyData.KeyState.KeyShiftState & (EFI_LEFT_CONTROL_PRESSED | EFI_RIGHT_CONTROL_PRESSED)) != 0) {
-    if (KeyData.Key.UnicodeChar >= L'a' &&
-        KeyData.Key.UnicodeChar <= L'z') {
-      KeyData.Key.UnicodeChar = (CHAR16) (KeyData.Key.UnicodeChar - L'a' + 1);
-    } else if (KeyData.Key.UnicodeChar >= L'A' &&
-               KeyData.Key.UnicodeChar <= L'Z') {
-      KeyData.Key.UnicodeChar = (CHAR16) (KeyData.Key.UnicodeChar - L'A' + 1);
+    if ((KeyData.Key.UnicodeChar >= L'a') &&
+        (KeyData.Key.UnicodeChar <= L'z'))
+    {
+      KeyData.Key.UnicodeChar = (CHAR16)(KeyData.Key.UnicodeChar - L'a' + 1);
+    } else if ((KeyData.Key.UnicodeChar >= L'A') &&
+               (KeyData.Key.UnicodeChar <= L'Z'))
+    {
+      KeyData.Key.UnicodeChar = (CHAR16)(KeyData.Key.UnicodeChar - L'A' + 1);
     }
   }
 
@@ -738,14 +741,14 @@ VirtualKeyboardReadKeyStroke (
 
 /**
   Reads the next keystroke from the input device. The WaitForKey Event can
-  be used to test for existance of a keystroke via WaitForEvent () call.
+  be used to test for existence of a keystroke via WaitForEvent () call.
 
   @param  This         Protocol instance pointer.
   @param  KeyData      A pointer to a buffer that is filled in with the
                        keystroke state data for the key that was pressed.
 
   @retval  EFI_SUCCESS           The keystroke information was returned.
-  @retval  EFI_NOT_READY         There was no keystroke data availiable.
+  @retval  EFI_NOT_READY         There was no keystroke data available.
   @retval  EFI_DEVICE_ERROR      The keystroke information was not returned
                                  due to hardware errors.
   @retval  EFI_INVALID_PARAMETER KeyData is NULL.
@@ -754,11 +757,11 @@ VirtualKeyboardReadKeyStroke (
 EFI_STATUS
 EFIAPI
 VirtualKeyboardReadKeyStrokeEx (
-  IN  EFI_SIMPLE_TEXT_INPUT_EX_PROTOCOL *This,
-  OUT EFI_KEY_DATA                      *KeyData
+  IN  EFI_SIMPLE_TEXT_INPUT_EX_PROTOCOL  *This,
+  OUT EFI_KEY_DATA                       *KeyData
   )
 {
-  VIRTUAL_KEYBOARD_DEV                  *VirtualKeyboardPrivate;
+  VIRTUAL_KEYBOARD_DEV  *VirtualKeyboardPrivate;
 
   if (KeyData == NULL) {
     return EFI_INVALID_PARAMETER;
@@ -767,7 +770,6 @@ VirtualKeyboardReadKeyStrokeEx (
   VirtualKeyboardPrivate = TEXT_INPUT_EX_VIRTUAL_KEYBOARD_DEV_FROM_THIS (This);
 
   return KeyboardReadKeyStrokeWorker (VirtualKeyboardPrivate, KeyData);
-
 }
 
 /**
@@ -815,7 +817,7 @@ VirtualKeyboardSetState (
 
   @retval EFI_SUCCESS             The notification function was registered
                                   successfully.
-  @retval EFI_OUT_OF_RESOURCES    Unable to allocate resources for necesssary
+  @retval EFI_OUT_OF_RESOURCES    Unable to allocate resources for necessary
                                   data structures.
   @retval EFI_INVALID_PARAMETER   KeyData or NotifyHandle is NULL.
 
@@ -829,16 +831,17 @@ VirtualKeyboardRegisterKeyNotify (
   OUT VOID                              **NotifyHandle
   )
 {
-  EFI_STATUS                            Status;
-  VIRTUAL_KEYBOARD_DEV                  *VirtualKeyboardPrivate;
-  EFI_TPL                               OldTpl;
-  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *NewNotify;
-  LIST_ENTRY                            *Link;
-  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *CurrentNotify;
+  EFI_STATUS                             Status;
+  VIRTUAL_KEYBOARD_DEV                   *VirtualKeyboardPrivate;
+  EFI_TPL                                OldTpl;
+  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY  *NewNotify;
+  LIST_ENTRY                             *Link;
+  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY  *CurrentNotify;
 
-  if (KeyData == NULL ||
-      NotifyHandle == NULL ||
-      KeyNotificationFunction == NULL) {
+  if ((KeyData == NULL) ||
+      (NotifyHandle == NULL) ||
+      (KeyNotificationFunction == NULL))
+  {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -855,7 +858,8 @@ VirtualKeyboardRegisterKeyNotify (
   //
   for (Link = VirtualKeyboardPrivate->NotifyList.ForwardLink;
        Link != &VirtualKeyboardPrivate->NotifyList;
-       Link = Link->ForwardLink) {
+       Link = Link->ForwardLink)
+  {
     CurrentNotify = CR (
                       Link,
                       VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY,
@@ -865,7 +869,7 @@ VirtualKeyboardRegisterKeyNotify (
     if (IsKeyRegistered (&CurrentNotify->KeyData, KeyData)) {
       if (CurrentNotify->KeyNotificationFn == KeyNotificationFunction) {
         *NotifyHandle = CurrentNotify;
-        Status = EFI_SUCCESS;
+        Status        = EFI_SUCCESS;
         goto Exit;
       }
     }
@@ -875,7 +879,7 @@ VirtualKeyboardRegisterKeyNotify (
   // Allocate resource to save the notification function
   //
 
-  NewNotify = (VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *) AllocateZeroPool (sizeof (VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY));
+  NewNotify = (VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *)AllocateZeroPool (sizeof (VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY));
   if (NewNotify == NULL) {
     Status = EFI_OUT_OF_RESOURCES;
     goto Exit;
@@ -886,8 +890,8 @@ VirtualKeyboardRegisterKeyNotify (
   CopyMem (&NewNotify->KeyData, KeyData, sizeof (EFI_KEY_DATA));
   InsertTailList (&VirtualKeyboardPrivate->NotifyList, &NewNotify->NotifyEntry);
 
-  *NotifyHandle                = NewNotify;
-  Status                       = EFI_SUCCESS;
+  *NotifyHandle = NewNotify;
+  Status        = EFI_SUCCESS;
 
 Exit:
   //
@@ -895,7 +899,6 @@ Exit:
   //
   gBS->RestoreTPL (OldTpl);
   return Status;
-
 }
 
 /**
@@ -917,11 +920,11 @@ VirtualKeyboardUnregisterKeyNotify (
   IN VOID                               *NotificationHandle
   )
 {
-  EFI_STATUS                            Status;
-  VIRTUAL_KEYBOARD_DEV                  *VirtualKeyboardPrivate;
-  EFI_TPL                               OldTpl;
-  LIST_ENTRY                            *Link;
-  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *CurrentNotify;
+  EFI_STATUS                             Status;
+  VIRTUAL_KEYBOARD_DEV                   *VirtualKeyboardPrivate;
+  EFI_TPL                                OldTpl;
+  LIST_ENTRY                             *Link;
+  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY  *CurrentNotify;
 
   //
   // Check incoming notification handle
@@ -930,8 +933,9 @@ VirtualKeyboardUnregisterKeyNotify (
     return EFI_INVALID_PARAMETER;
   }
 
-  if (((VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *) NotificationHandle)->Signature !=
-      VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY_SIGNATURE) {
+  if (((VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *)NotificationHandle)->Signature !=
+      VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY_SIGNATURE)
+  {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -944,7 +948,8 @@ VirtualKeyboardUnregisterKeyNotify (
 
   for (Link = VirtualKeyboardPrivate->NotifyList.ForwardLink;
        Link != &VirtualKeyboardPrivate->NotifyList;
-       Link = Link->ForwardLink) {
+       Link = Link->ForwardLink)
+  {
     CurrentNotify = CR (
                       Link,
                       VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY,
@@ -989,8 +994,8 @@ Exit:
 VOID
 EFIAPI
 VirtualKeyboardTimerHandler (
-  IN EFI_EVENT    Event,
-  IN VOID         *Context
+  IN EFI_EVENT  Event,
+  IN VOID       *Context
   )
 {
   EFI_TPL                                OldTpl;
@@ -1008,14 +1013,17 @@ VirtualKeyboardTimerHandler (
   OldTpl = gBS->RaiseTPL (TPL_NOTIFY);
 
   if (VirtualKeyboardPrivate->PlatformVirtual &&
-      VirtualKeyboardPrivate->PlatformVirtual->Query) {
+      VirtualKeyboardPrivate->PlatformVirtual->Query)
+  {
     if (VirtualKeyboardPrivate->PlatformVirtual->Query (&VirtualKey) ==
-        FALSE) {
+        FALSE)
+    {
       goto Exit;
     }
+
     // Found key
-    KeyData.Key.ScanCode = VirtualKey.Key.ScanCode;
-    KeyData.Key.UnicodeChar = VirtualKey.Key.UnicodeChar;
+    KeyData.Key.ScanCode            = VirtualKey.Key.ScanCode;
+    KeyData.Key.UnicodeChar         = VirtualKey.Key.UnicodeChar;
     KeyData.KeyState.KeyShiftState  = EFI_SHIFT_STATE_VALID;
     KeyData.KeyState.KeyToggleState = EFI_TOGGLE_STATE_VALID;
     if (VirtualKeyboardPrivate->PlatformVirtual->Clear) {
@@ -1030,7 +1038,8 @@ VirtualKeyboardTimerHandler (
   //
   for (Link = VirtualKeyboardPrivate->NotifyList.ForwardLink;
        Link != &VirtualKeyboardPrivate->NotifyList;
-       Link = Link->ForwardLink) {
+       Link = Link->ForwardLink)
+  {
     CurrentNotify = CR (
                       Link,
                       VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY,
@@ -1067,19 +1076,19 @@ Exit:
 VOID
 EFIAPI
 KeyNotifyProcessHandler (
-  IN  EFI_EVENT                 Event,
-  IN  VOID                      *Context
+  IN  EFI_EVENT  Event,
+  IN  VOID       *Context
   )
 {
-  EFI_STATUS                            Status;
-  VIRTUAL_KEYBOARD_DEV                  *VirtualKeyboardPrivate;
-  EFI_KEY_DATA                          KeyData;
-  LIST_ENTRY                            *Link;
-  LIST_ENTRY                            *NotifyList;
-  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY *CurrentNotify;
-  EFI_TPL                               OldTpl;
+  EFI_STATUS                             Status;
+  VIRTUAL_KEYBOARD_DEV                   *VirtualKeyboardPrivate;
+  EFI_KEY_DATA                           KeyData;
+  LIST_ENTRY                             *Link;
+  LIST_ENTRY                             *NotifyList;
+  VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY  *CurrentNotify;
+  EFI_TPL                                OldTpl;
 
-  VirtualKeyboardPrivate = (VIRTUAL_KEYBOARD_DEV *) Context;
+  VirtualKeyboardPrivate = (VIRTUAL_KEYBOARD_DEV *)Context;
 
   //
   // Invoke notification functions.
@@ -1098,10 +1107,13 @@ KeyNotifyProcessHandler (
     if (EFI_ERROR (Status)) {
       break;
     }
+
     for (Link = GetFirstNode (NotifyList);
          !IsNull (NotifyList, Link);
-         Link = GetNextNode (NotifyList, Link)) {
-      CurrentNotify = CR (Link,
+         Link = GetNextNode (NotifyList, Link))
+    {
+      CurrentNotify = CR (
+                        Link,
                         VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY,
                         NotifyEntry,
                         VIRTUAL_KEYBOARD_CONSOLE_IN_EX_NOTIFY_SIGNATURE
@@ -1126,12 +1138,12 @@ KeyNotifyProcessHandler (
 **/
 EFI_STATUS
 EFIAPI
-InitializeVirtualKeyboard(
-  IN EFI_HANDLE           ImageHandle,
-  IN EFI_SYSTEM_TABLE     *SystemTable
+InitializeVirtualKeyboard (
+  IN EFI_HANDLE        ImageHandle,
+  IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
-  EFI_STATUS              Status;
+  EFI_STATUS  Status;
 
   //
   // Install driver model protocol(s).
