@@ -3,6 +3,7 @@
 
   Copyright (c) 2008 - 2009, Apple Inc. All rights reserved.<BR>
   Copyright (c) 2017, Linaro, Ltd. All rights reserved.<BR>
+  Copyright (c) 2021, Ampere Computing LLC. All rights reserved.<BR>
 
   SPDX-License-Identifier: BSD-2-Clause-Patent
 
@@ -11,6 +12,7 @@
 #include <PiDxe.h>
 #include <Library/DebugLib.h>
 #include <Library/RealTimeClockLib.h>
+#include <Library/TimeBaseLib.h>
 #include <Library/UefiLib.h>
 #include <Library/UefiBootServicesTableLib.h>
 #include <Library/UefiRuntimeLib.h>
@@ -24,98 +26,12 @@ EFI_HANDLE  mHandle = NULL;
 // variable instead.
 //
 typedef struct {
-  INT16           TimeZone;
-  UINT8           Daylight;
+  INT16    TimeZone;
+  UINT8    Daylight;
 } NON_VOLATILE_TIME_SETTINGS;
 
-STATIC CONST CHAR16 mTimeSettingsVariableName[] = L"RtcTimeSettings";
-STATIC NON_VOLATILE_TIME_SETTINGS mTimeSettings;
-
-STATIC
-BOOLEAN
-IsValidTimeZone (
-  IN  INT16  TimeZone
-  )
-{
-  return TimeZone == EFI_UNSPECIFIED_TIMEZONE ||
-         (TimeZone >= -1440 && TimeZone <= 1440);
-}
-
-STATIC
-BOOLEAN
-IsValidDaylight (
-  IN  INT8  Daylight
-  )
-{
-  return Daylight == 0 ||
-         Daylight == EFI_TIME_ADJUST_DAYLIGHT ||
-         Daylight == (EFI_TIME_ADJUST_DAYLIGHT | EFI_TIME_IN_DAYLIGHT);
-}
-
-STATIC
-BOOLEAN
-EFIAPI
-IsLeapYear (
-  IN EFI_TIME   *Time
-  )
-{
-  if (Time->Year % 4 == 0) {
-    if (Time->Year % 100 == 0) {
-      if (Time->Year % 400 == 0) {
-        return TRUE;
-      } else {
-        return FALSE;
-      }
-    } else {
-      return TRUE;
-    }
-  } else {
-    return FALSE;
-  }
-}
-
-STATIC CONST INTN mDayOfMonth[12] = {
-  31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31
-};
-
-STATIC
-BOOLEAN
-EFIAPI
-IsDayValid (
-  IN  EFI_TIME  *Time
-  )
-{
-  if (Time->Day < 1 ||
-      Time->Day > mDayOfMonth[Time->Month - 1] ||
-      (Time->Month == 2 && !IsLeapYear (Time) && Time->Day > 28)) {
-    return FALSE;
-  }
-  return TRUE;
-}
-
-STATIC
-BOOLEAN
-EFIAPI
-IsTimeValid(
-  IN EFI_TIME *Time
-  )
-{
-  // Check the input parameters are within the range specified by UEFI
-  if (Time->Year   < 1900               ||
-      Time->Year   > 9999               ||
-      Time->Month  < 1                  ||
-      Time->Month  > 12                 ||
-      !IsDayValid (Time)                ||
-      Time->Hour   > 23                 ||
-      Time->Minute > 59                 ||
-      Time->Second > 59                 ||
-      Time->Nanosecond > 999999999      ||
-      !IsValidTimeZone (Time->TimeZone) ||
-      !IsValidDaylight (Time->Daylight)) {
-    return FALSE;
-  }
-  return TRUE;
-}
+STATIC CONST CHAR16                mTimeSettingsVariableName[] = L"RtcTimeSettings";
+STATIC NON_VOLATILE_TIME_SETTINGS  mTimeSettings;
 
 /**
   Returns the current time and date information, and the time-keeping capabilities
@@ -133,8 +49,8 @@ IsTimeValid(
 EFI_STATUS
 EFIAPI
 GetTime (
-  OUT EFI_TIME                *Time,
-  OUT EFI_TIME_CAPABILITIES   *Capabilities
+  OUT EFI_TIME               *Time,
+  OUT EFI_TIME_CAPABILITIES  *Capabilities
   )
 {
   if (Time == NULL) {
@@ -151,8 +67,6 @@ GetTime (
   return LibGetTime (Time, Capabilities);
 }
 
-
-
 /**
   Sets the current local time and date information.
 
@@ -160,29 +74,29 @@ GetTime (
 
   @retval EFI_SUCCESS           The operation completed successfully.
   @retval EFI_INVALID_PARAMETER A time field is out of range.
-  @retval EFI_DEVICE_ERROR      The time could not be set due due to hardware error.
+  @retval EFI_DEVICE_ERROR      The time could not be set due to hardware error.
 
 **/
 EFI_STATUS
 EFIAPI
 SetTime (
-  IN EFI_TIME                *Time
+  IN EFI_TIME  *Time
   )
 {
-  EFI_STATUS        Status;
-  BOOLEAN           TimeSettingsChanged;
+  EFI_STATUS  Status;
+  BOOLEAN     TimeSettingsChanged;
 
-  if (Time == NULL || !IsTimeValid (Time)) {
+  if ((Time == NULL) || !IsTimeValid (Time)) {
     return EFI_INVALID_PARAMETER;
   }
 
   TimeSettingsChanged = FALSE;
-  if (mTimeSettings.TimeZone != Time->TimeZone ||
-      mTimeSettings.Daylight != Time->Daylight) {
-
+  if ((mTimeSettings.TimeZone != Time->TimeZone) ||
+      (mTimeSettings.Daylight != Time->Daylight))
+  {
     mTimeSettings.TimeZone = Time->TimeZone;
     mTimeSettings.Daylight = Time->Daylight;
-    TimeSettingsChanged = TRUE;
+    TimeSettingsChanged    = TRUE;
   }
 
   Status = LibSetTime (Time);
@@ -198,15 +112,16 @@ SetTime (
                EFI_VARIABLE_BOOTSERVICE_ACCESS |
                EFI_VARIABLE_RUNTIME_ACCESS,
                sizeof (mTimeSettings),
-               (VOID *)&mTimeSettings);
+               (VOID *)&mTimeSettings
+               );
     if (EFI_ERROR (Status)) {
       return EFI_DEVICE_ERROR;
     }
   }
+
   return EFI_SUCCESS;
 }
 
-
 /**
   Returns the current wakeup alarm clock setting.
 
@@ -222,15 +137,25 @@ SetTime (
 EFI_STATUS
 EFIAPI
 GetWakeupTime (
-  OUT BOOLEAN     *Enabled,
-  OUT BOOLEAN     *Pending,
-  OUT EFI_TIME    *Time
+  OUT BOOLEAN   *Enabled,
+  OUT BOOLEAN   *Pending,
+  OUT EFI_TIME  *Time
   )
 {
+  if ((Time == NULL) || (Enabled == NULL) || (Pending == NULL)) {
+    return EFI_INVALID_PARAMETER;
+  }
+
+  //
+  // Set these first so the RealTimeClockLib implementation
+  // can override them based on its own settings.
+  //
+  Time->TimeZone = mTimeSettings.TimeZone;
+  Time->Daylight = mTimeSettings.Daylight;
+
   return LibGetWakeupTime (Enabled, Pending, Time);
 }
 
-
 /**
   Sets the system wakeup alarm clock time.
 
@@ -247,15 +172,13 @@ GetWakeupTime (
 EFI_STATUS
 EFIAPI
 SetWakeupTime (
-  IN BOOLEAN      Enabled,
-  OUT EFI_TIME    *Time
+  IN BOOLEAN    Enabled,
+  OUT EFI_TIME  *Time
   )
 {
   return LibSetWakeupTime (Enabled, Time);
 }
 
-
-
 /**
   This is the declaration of an EFI image entry point. This can be the entry point to an application
   written to this specification, an EFI boot service driver, or an EFI runtime driver.
@@ -269,8 +192,8 @@ SetWakeupTime (
 EFI_STATUS
 EFIAPI
 InitializeRealTimeClock (
-  IN EFI_HANDLE                            ImageHandle,
-  IN EFI_SYSTEM_TABLE                      *SystemTable
+  IN EFI_HANDLE        ImageHandle,
+  IN EFI_SYSTEM_TABLE  *SystemTable
   )
 {
   EFI_STATUS  Status;
@@ -281,14 +204,23 @@ InitializeRealTimeClock (
     return Status;
   }
 
-  Size = sizeof (mTimeSettings);
-  Status = EfiGetVariable ((CHAR16 *)mTimeSettingsVariableName,
-             &gEfiCallerIdGuid, NULL, &Size, (VOID *)&mTimeSettings);
+  Size   = sizeof (mTimeSettings);
+  Status = EfiGetVariable (
+             (CHAR16 *)mTimeSettingsVariableName,
+             &gEfiCallerIdGuid,
+             NULL,
+             &Size,
+             (VOID *)&mTimeSettings
+             );
   if (EFI_ERROR (Status) ||
       !IsValidTimeZone (mTimeSettings.TimeZone) ||
-      !IsValidDaylight (mTimeSettings.Daylight)) {
-    DEBUG ((DEBUG_WARN, "%a: using default timezone/daylight settings\n",
-      __FUNCTION__));
+      !IsValidDaylight (mTimeSettings.Daylight))
+  {
+    DEBUG ((
+      DEBUG_WARN,
+      "%a: using default timezone/daylight settings\n",
+      __FUNCTION__
+      ));
 
     mTimeSettings.TimeZone = EFI_UNSPECIFIED_TIMEZONE;
     mTimeSettings.Daylight = 0;
@@ -308,4 +240,3 @@ InitializeRealTimeClock (
 
   return Status;
 }
-
