@@ -2,16 +2,9 @@
   The NvmExpressPei driver is used to manage non-volatile memory subsystem
   which follows NVM Express specification at PEI phase.
 
-  Copyright (c) 2018, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2018 - 2019, Intel Corporation. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions
-  of the BSD License which accompanies this distribution.  The
-  full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -31,27 +24,29 @@
 **/
 EFI_STATUS
 ReadSectors (
-  IN  PEI_NVME_NAMESPACE_INFO    *NamespaceInfo,
-  OUT UINTN                      Buffer,
-  IN  UINT64                     Lba,
-  IN  UINT32                     Blocks
+  IN  PEI_NVME_NAMESPACE_INFO  *NamespaceInfo,
+  OUT UINTN                    Buffer,
+  IN  UINT64                   Lba,
+  IN  UINT32                   Blocks
   )
 {
-  EFI_STATUS                                        Status;
-  UINT32                                            BlockSize;
-  PEI_NVME_CONTROLLER_PRIVATE_DATA                  *Private;
-  UINT32                                            Bytes;
-  EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET    CommandPacket;
-  EDKII_PEI_NVM_EXPRESS_COMMAND                     Command;
-  EDKII_PEI_NVM_EXPRESS_COMPLETION                  Completion;
+  EFI_STATUS                                Status;
+  UINT32                                    BlockSize;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA          *Private;
+  UINT32                                    Bytes;
+  EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  CommandPacket;
+  EFI_NVM_EXPRESS_COMMAND                   Command;
+  EFI_NVM_EXPRESS_COMPLETION                Completion;
+  EDKII_PEI_NVM_EXPRESS_PASS_THRU_PPI       *NvmePassThru;
 
-  Private   = NamespaceInfo->Controller;
-  BlockSize = NamespaceInfo->Media.BlockSize;
-  Bytes     = Blocks * BlockSize;
+  Private      = NamespaceInfo->Controller;
+  NvmePassThru = &Private->NvmePassThruPpi;
+  BlockSize    = NamespaceInfo->Media.BlockSize;
+  Bytes        = Blocks * BlockSize;
 
-  ZeroMem (&CommandPacket, sizeof(EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
-  ZeroMem (&Command, sizeof(EDKII_PEI_NVM_EXPRESS_COMMAND));
-  ZeroMem (&Completion, sizeof(EDKII_PEI_NVM_EXPRESS_COMPLETION));
+  ZeroMem (&CommandPacket, sizeof (EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
+  ZeroMem (&Command, sizeof (EFI_NVM_EXPRESS_COMMAND));
+  ZeroMem (&Completion, sizeof (EFI_NVM_EXPRESS_COMPLETION));
 
   CommandPacket.NvmeCmd        = &Command;
   CommandPacket.NvmeCompletion = &Completion;
@@ -65,16 +60,17 @@ ReadSectors (
   CommandPacket.QueueType      = NVME_IO_QUEUE;
 
   CommandPacket.NvmeCmd->Cdw10 = (UINT32)Lba;
-  CommandPacket.NvmeCmd->Cdw11 = (UINT32)RShiftU64(Lba, 32);
+  CommandPacket.NvmeCmd->Cdw11 = (UINT32)RShiftU64 (Lba, 32);
   CommandPacket.NvmeCmd->Cdw12 = (Blocks - 1) & 0xFFFF;
 
   CommandPacket.NvmeCmd->Flags = CDW10_VALID | CDW11_VALID | CDW12_VALID;
 
-  Status = NvmePassThru (
-             Private,
-             NamespaceInfo->NamespaceId,
-             &CommandPacket
-             );
+  Status = NvmePassThru->PassThru (
+                           NvmePassThru,
+                           NamespaceInfo->NamespaceId,
+                           &CommandPacket
+                           );
+
   return Status;
 }
 
@@ -92,18 +88,18 @@ ReadSectors (
 **/
 EFI_STATUS
 NvmeRead (
-  IN  PEI_NVME_NAMESPACE_INFO    *NamespaceInfo,
-  OUT UINTN                      Buffer,
-  IN  UINT64                     Lba,
-  IN  UINTN                      Blocks
+  IN  PEI_NVME_NAMESPACE_INFO  *NamespaceInfo,
+  OUT UINTN                    Buffer,
+  IN  UINT64                   Lba,
+  IN  UINTN                    Blocks
   )
 {
-  EFI_STATUS                          Status;
-  UINT32                              Retries;
-  UINT32                              BlockSize;
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
-  UINT32                              MaxTransferBlocks;
-  UINTN                               OrginalBlocks;
+  EFI_STATUS                        Status;
+  UINT32                            Retries;
+  UINT32                            BlockSize;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
+  UINT32                            MaxTransferBlocks;
+  UINTN                             OrginalBlocks;
 
   Status        = EFI_SUCCESS;
   Retries       = 0;
@@ -124,14 +120,15 @@ NvmeRead (
                Lba,
                Blocks > MaxTransferBlocks ? MaxTransferBlocks : (UINT32)Blocks
                );
-    if (EFI_ERROR(Status)) {
+    if (EFI_ERROR (Status)) {
       Retries++;
       MaxTransferBlocks = MaxTransferBlocks >> 1;
 
-      if (Retries > NVME_READ_MAX_RETRY || MaxTransferBlocks < 1) {
+      if ((Retries > NVME_READ_MAX_RETRY) || (MaxTransferBlocks < 1)) {
         DEBUG ((DEBUG_ERROR, "%a: ReadSectors fail, Status - %r\n", __FUNCTION__, Status));
         break;
       }
+
       DEBUG ((
         DEBUG_BLKIO,
         "%a: ReadSectors fail, retry with smaller transfer block number - 0x%x\n",
@@ -146,13 +143,21 @@ NvmeRead (
       Buffer += (MaxTransferBlocks * BlockSize);
       Lba    += MaxTransferBlocks;
     } else {
-      Blocks  = 0;
+      Blocks = 0;
     }
   }
 
-  DEBUG ((DEBUG_BLKIO, "%a: Lba = 0x%08Lx, Original = 0x%08Lx, "
-    "Remaining = 0x%08Lx, BlockSize = 0x%x, Status = %r\n", __FUNCTION__, Lba,
-    (UINT64)OrginalBlocks, (UINT64)Blocks, BlockSize, Status));
+  DEBUG ((
+    DEBUG_BLKIO,
+    "%a: Lba = 0x%08Lx, Original = 0x%08Lx, "
+    "Remaining = 0x%08Lx, BlockSize = 0x%x, Status = %r\n",
+    __FUNCTION__,
+    Lba,
+    (UINT64)OrginalBlocks,
+    (UINT64)Blocks,
+    BlockSize,
+    Status
+    ));
   return Status;
 }
 
@@ -180,13 +185,13 @@ NvmeBlockIoPeimGetDeviceNo (
   OUT UINTN                          *NumberBlockDevices
   )
 {
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
 
-  if (This == NULL || NumberBlockDevices == NULL) {
+  if ((This == NULL) || (NumberBlockDevices == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
-  Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_BLKIO (This);
+  Private             = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_BLKIO (This);
   *NumberBlockDevices = Private->ActiveNamespaceNum;
 
   return EFI_SUCCESS;
@@ -242,9 +247,9 @@ NvmeBlockIoPeimGetMediaInfo (
   OUT EFI_PEI_BLOCK_IO_MEDIA         *MediaInfo
   )
 {
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
 
-  if (This == NULL || MediaInfo == NULL) {
+  if ((This == NULL) || (MediaInfo == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -254,7 +259,7 @@ NvmeBlockIoPeimGetMediaInfo (
     return EFI_INVALID_PARAMETER;
   }
 
-  MediaInfo->DeviceType   = (EFI_PEI_BLOCK_DEVICE_TYPE) EDKII_PEI_BLOCK_DEVICE_TYPE_NVME;
+  MediaInfo->DeviceType   = (EFI_PEI_BLOCK_DEVICE_TYPE)EDKII_PEI_BLOCK_DEVICE_TYPE_NVME;
   MediaInfo->MediaPresent = TRUE;
   MediaInfo->LastBlock    = (UINTN)Private->NamespaceInfo[DeviceIndex-1].Media.LastBlock;
   MediaInfo->BlockSize    = Private->NamespaceInfo[DeviceIndex-1].Media.BlockSize;
@@ -307,17 +312,17 @@ NvmeBlockIoPeimReadBlocks (
   OUT VOID                           *Buffer
   )
 {
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
-  PEI_NVME_NAMESPACE_INFO             *NamespaceInfo;
-  UINT32                              BlockSize;
-  UINTN                               NumberOfBlocks;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
+  PEI_NVME_NAMESPACE_INFO           *NamespaceInfo;
+  UINT32                            BlockSize;
+  UINTN                             NumberOfBlocks;
 
   Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_BLKIO (This);
 
   //
   // Check parameters
   //
-  if (This == NULL || Buffer == NULL) {
+  if ((This == NULL) || (Buffer == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -333,7 +338,7 @@ NvmeBlockIoPeimReadBlocks (
   // Check BufferSize and StartLBA
   //
   NamespaceInfo = &(Private->NamespaceInfo[DeviceIndex - 1]);
-  BlockSize = NamespaceInfo->Media.BlockSize;
+  BlockSize     = NamespaceInfo->Media.BlockSize;
   if (BufferSize % BlockSize != 0) {
     return EFI_BAD_BUFFER_SIZE;
   }
@@ -341,6 +346,7 @@ NvmeBlockIoPeimReadBlocks (
   if (StartLBA > NamespaceInfo->Media.LastBlock) {
     return EFI_INVALID_PARAMETER;
   }
+
   NumberOfBlocks = BufferSize / BlockSize;
   if (NumberOfBlocks - 1 > NamespaceInfo->Media.LastBlock - StartLBA) {
     return EFI_INVALID_PARAMETER;
@@ -373,13 +379,13 @@ NvmeBlockIoPeimGetDeviceNo2 (
   OUT UINTN                           *NumberBlockDevices
   )
 {
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
 
-  if (This == NULL || NumberBlockDevices == NULL) {
+  if ((This == NULL) || (NumberBlockDevices == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
-  Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_BLKIO2 (This);
+  Private             = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_BLKIO2 (This);
   *NumberBlockDevices = Private->ActiveNamespaceNum;
 
   return EFI_SUCCESS;
@@ -435,22 +441,22 @@ NvmeBlockIoPeimGetMediaInfo2 (
   OUT EFI_PEI_BLOCK_IO2_MEDIA         *MediaInfo
   )
 {
-  EFI_STATUS                          Status;
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
-  EFI_PEI_BLOCK_IO_MEDIA              Media;
+  EFI_STATUS                        Status;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
+  EFI_PEI_BLOCK_IO_MEDIA            Media;
 
-  if (This == NULL || MediaInfo == NULL) {
+  if ((This == NULL) || (MediaInfo == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
   Private = GET_NVME_PEIM_HC_PRIVATE_DATA_FROM_THIS_BLKIO2 (This);
 
-  Status  = NvmeBlockIoPeimGetMediaInfo (
-              PeiServices,
-              &Private->BlkIoPpi,
-              DeviceIndex,
-              &Media
-              );
+  Status = NvmeBlockIoPeimGetMediaInfo (
+             PeiServices,
+             &Private->BlkIoPpi,
+             DeviceIndex,
+             &Media
+             );
   if (EFI_ERROR (Status)) {
     return Status;
   }
@@ -509,7 +515,7 @@ NvmeBlockIoPeimReadBlocks2 (
   OUT VOID                            *Buffer
   )
 {
-  PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private;
+  PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private;
 
   if (This == NULL) {
     return EFI_INVALID_PARAMETER;
