@@ -2,16 +2,9 @@
   The NvmExpressPei driver is used to manage non-volatile memory subsystem
   which follows NVM Express specification at PEI phase.
 
-  Copyright (c) 2018, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2018 - 2019, Intel Corporation. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions
-  of the BSD License which accompanies this distribution.  The
-  full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -29,14 +22,14 @@
 **/
 EFI_STATUS
 NvmeMmioRead (
-  IN OUT VOID *MemBuffer,
-  IN     UINTN MmioAddr,
-  IN     UINTN Size
+  IN OUT VOID   *MemBuffer,
+  IN     UINTN  MmioAddr,
+  IN     UINTN  Size
   )
 {
-  UINTN    Offset;
-  UINT8    Data;
-  UINT8    *Ptr;
+  UINTN  Offset;
+  UINT8  Data;
+  UINT8  *Ptr;
 
   // priority has adjusted
   switch (Size) {
@@ -59,9 +52,10 @@ NvmeMmioRead (
     default:
       Ptr = (UINT8 *)MemBuffer;
       for (Offset = 0; Offset < Size; Offset += 1) {
-        Data = MmioRead8 (MmioAddr + Offset);
+        Data        = MmioRead8 (MmioAddr + Offset);
         Ptr[Offset] = Data;
       }
+
       break;
   }
 
@@ -80,14 +74,14 @@ NvmeMmioRead (
 **/
 EFI_STATUS
 NvmeMmioWrite (
-  IN OUT UINTN MmioAddr,
-  IN     VOID *MemBuffer,
-  IN     UINTN Size
+  IN OUT UINTN  MmioAddr,
+  IN     VOID   *MemBuffer,
+  IN     UINTN  Size
   )
 {
-  UINTN    Offset;
-  UINT8    Data;
-  UINT8    *Ptr;
+  UINTN  Offset;
+  UINT8  Data;
+  UINT8  *Ptr;
 
   // priority has adjusted
   switch (Size) {
@@ -113,6 +107,7 @@ NvmeMmioWrite (
         Data = Ptr[Offset];
         MmioWrite8 (MmioAddr + Offset, Data);
       }
+
       break;
   }
 
@@ -129,18 +124,18 @@ NvmeMmioWrite (
 **/
 UINT32
 NvmeBaseMemPageOffset (
-  IN UINTN              BaseMemIndex
+  IN UINTN  BaseMemIndex
   )
 {
-  UINT32                Pages;
-  UINTN                 Index;
-  UINT32                PageSizeList[5];
+  UINT32  Pages;
+  UINTN   Index;
+  UINT32  PageSizeList[5];
 
-  PageSizeList[0] = 1;  /* ASQ */
-  PageSizeList[1] = 1;  /* ACQ */
-  PageSizeList[2] = 1;  /* SQs */
-  PageSizeList[3] = 1;  /* CQs */
-  PageSizeList[4] = NVME_PRP_SIZE;  /* PRPs */
+  PageSizeList[0] = 1;             /* ASQ */
+  PageSizeList[1] = 1;             /* ACQ */
+  PageSizeList[2] = 1;             /* SQs */
+  PageSizeList[3] = 1;             /* CQs */
+  PageSizeList[4] = NVME_PRP_SIZE; /* PRPs */
 
   if (BaseMemIndex > MAX_BASEMEM_COUNT) {
     DEBUG ((DEBUG_ERROR, "%a: The input BaseMem index is invalid.\n", __FUNCTION__));
@@ -168,14 +163,14 @@ NvmeBaseMemPageOffset (
 **/
 EFI_STATUS
 NvmeWaitController (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private,
-  IN BOOLEAN                             WaitReady
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private,
+  IN BOOLEAN                           WaitReady
   )
 {
-  NVME_CSTS              Csts;
-  EFI_STATUS             Status;
-  UINT32                 Index;
-  UINT8                  Timeout;
+  NVME_CSTS   Csts;
+  EFI_STATUS  Status;
+  UINT32      Index;
+  UINT8       Timeout;
 
   //
   // Cap.To specifies max delay time in 500ms increments for Csts.Rdy to set after
@@ -188,19 +183,19 @@ NvmeWaitController (
   }
 
   Status = EFI_SUCCESS;
-  for(Index = (Timeout * 500); Index != 0; --Index) {
+  for (Index = (Timeout * 500); Index != 0; --Index) {
     MicroSecondDelay (1000);
 
     //
     // Check if the controller is initialized
     //
     Status = NVME_GET_CSTS (Private, &Csts);
-    if (EFI_ERROR(Status)) {
+    if (EFI_ERROR (Status)) {
       DEBUG ((DEBUG_ERROR, "%a: NVME_GET_CSTS fail, Status - %r\n", __FUNCTION__, Status));
       return Status;
     }
 
-    if ((BOOLEAN) Csts.Rdy == WaitReady) {
+    if ((BOOLEAN)Csts.Rdy == WaitReady) {
       break;
     }
   }
@@ -223,12 +218,12 @@ NvmeWaitController (
 **/
 EFI_STATUS
 NvmeDisableController (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private
   )
 {
-  NVME_CC       Cc;
-  NVME_CSTS     Csts;
-  EFI_STATUS    Status;
+  NVME_CC     Cc;
+  NVME_CSTS   Csts;
+  EFI_STATUS  Status;
 
   Status = NVME_GET_CSTS (Private, &Csts);
 
@@ -278,11 +273,11 @@ ErrorExit:
 **/
 EFI_STATUS
 NvmeEnableController (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private
   )
 {
-  NVME_CC       Cc;
-  EFI_STATUS    Status;
+  NVME_CC     Cc;
+  EFI_STATUS  Status;
 
   //
   // Enable the controller
@@ -323,25 +318,25 @@ ErrorExit:
 **/
 EFI_STATUS
 NvmeIdentifyController (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private,
-  IN VOID                                *Buffer
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private,
+  IN VOID                              *Buffer
   )
 {
-  EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET    CommandPacket;
-  EDKII_PEI_NVM_EXPRESS_COMMAND                     Command;
-  EDKII_PEI_NVM_EXPRESS_COMPLETION                  Completion;
-  EFI_STATUS                                        Status;
+  EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  CommandPacket;
+  EFI_NVM_EXPRESS_COMMAND                   Command;
+  EFI_NVM_EXPRESS_COMPLETION                Completion;
+  EFI_STATUS                                Status;
 
-  ZeroMem (&CommandPacket, sizeof(EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
-  ZeroMem (&Command, sizeof(EDKII_PEI_NVM_EXPRESS_COMMAND));
-  ZeroMem (&Completion, sizeof(EDKII_PEI_NVM_EXPRESS_COMPLETION));
+  ZeroMem (&CommandPacket, sizeof (EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
+  ZeroMem (&Command, sizeof (EFI_NVM_EXPRESS_COMMAND));
+  ZeroMem (&Completion, sizeof (EFI_NVM_EXPRESS_COMPLETION));
 
   Command.Cdw0.Opcode = NVME_ADMIN_IDENTIFY_CMD;
   //
   // According to Nvm Express 1.1 spec Figure 38, When not used, the field shall be cleared to 0h.
   // For the Identify command, the Namespace Identifier is only used for the Namespace Data structure.
   //
-  Command.Nsid        = 0;
+  Command.Nsid = 0;
 
   CommandPacket.NvmeCmd        = &Command;
   CommandPacket.NvmeCompletion = &Completion;
@@ -355,7 +350,7 @@ NvmeIdentifyController (
   CommandPacket.NvmeCmd->Cdw10 = 1;
   CommandPacket.NvmeCmd->Flags = CDW10_VALID;
 
-  Status = NvmePassThru (
+  Status = NvmePassThruExecute (
              Private,
              NVME_CONTROLLER_NSID,
              &CommandPacket
@@ -376,19 +371,19 @@ NvmeIdentifyController (
 **/
 EFI_STATUS
 NvmeIdentifyNamespace (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private,
-  IN UINT32                              NamespaceId,
-  IN VOID                                *Buffer
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private,
+  IN UINT32                            NamespaceId,
+  IN VOID                              *Buffer
   )
 {
-  EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET    CommandPacket;
-  EDKII_PEI_NVM_EXPRESS_COMMAND                     Command;
-  EDKII_PEI_NVM_EXPRESS_COMPLETION                  Completion;
-  EFI_STATUS                                        Status;
+  EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  CommandPacket;
+  EFI_NVM_EXPRESS_COMMAND                   Command;
+  EFI_NVM_EXPRESS_COMPLETION                Completion;
+  EFI_STATUS                                Status;
 
-  ZeroMem (&CommandPacket, sizeof(EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
-  ZeroMem (&Command, sizeof(EDKII_PEI_NVM_EXPRESS_COMMAND));
-  ZeroMem (&Completion, sizeof(EDKII_PEI_NVM_EXPRESS_COMPLETION));
+  ZeroMem (&CommandPacket, sizeof (EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
+  ZeroMem (&Command, sizeof (EFI_NVM_EXPRESS_COMMAND));
+  ZeroMem (&Completion, sizeof (EFI_NVM_EXPRESS_COMPLETION));
 
   Command.Cdw0.Opcode = NVME_ADMIN_IDENTIFY_CMD;
   Command.Nsid        = NamespaceId;
@@ -405,7 +400,7 @@ NvmeIdentifyNamespace (
   CommandPacket.NvmeCmd->Cdw10 = 0;
   CommandPacket.NvmeCmd->Flags = CDW10_VALID;
 
-  Status = NvmePassThru (
+  Status = NvmePassThruExecute (
              Private,
              NamespaceId,
              &CommandPacket
@@ -421,11 +416,11 @@ NvmeIdentifyNamespace (
 **/
 VOID
 NvmeDumpControllerData (
-  IN NVME_ADMIN_CONTROLLER_DATA    *ControllerData
+  IN NVME_ADMIN_CONTROLLER_DATA  *ControllerData
   )
 {
-  UINT8    Sn[21];
-  UINT8    Mn[41];
+  UINT8  Sn[21];
+  UINT8  Mn[41];
 
   CopyMem (Sn, ControllerData->Sn, sizeof (ControllerData->Sn));
   Sn[20] = 0;
@@ -435,11 +430,11 @@ NvmeDumpControllerData (
   DEBUG ((DEBUG_INFO, " == NVME IDENTIFY CONTROLLER DATA ==\n"));
   DEBUG ((DEBUG_INFO, "    PCI VID   : 0x%x\n", ControllerData->Vid));
   DEBUG ((DEBUG_INFO, "    PCI SSVID : 0x%x\n", ControllerData->Ssvid));
-  DEBUG ((DEBUG_INFO, "    SN        : %a\n",   Sn));
-  DEBUG ((DEBUG_INFO, "    MN        : %a\n",   Mn));
-  DEBUG ((DEBUG_INFO, "    FR        : 0x%lx\n", *((UINT64*)ControllerData->Fr)));
+  DEBUG ((DEBUG_INFO, "    SN        : %a\n", Sn));
+  DEBUG ((DEBUG_INFO, "    MN        : %a\n", Mn));
+  DEBUG ((DEBUG_INFO, "    FR        : 0x%lx\n", *((UINT64 *)ControllerData->Fr)));
   DEBUG ((DEBUG_INFO, "    RAB       : 0x%x\n", ControllerData->Rab));
-  DEBUG ((DEBUG_INFO, "    IEEE      : 0x%x\n", *(UINT32*)ControllerData->Ieee_oui));
+  DEBUG ((DEBUG_INFO, "    IEEE      : 0x%x\n", *(UINT32 *)ControllerData->Ieee_oui));
   DEBUG ((DEBUG_INFO, "    AERL      : 0x%x\n", ControllerData->Aerl));
   DEBUG ((DEBUG_INFO, "    SQES      : 0x%x\n", ControllerData->Sqes));
   DEBUG ((DEBUG_INFO, "    CQES      : 0x%x\n", ControllerData->Cqes));
@@ -458,25 +453,24 @@ NvmeDumpControllerData (
 **/
 EFI_STATUS
 NvmeCreateIoCompletionQueue (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private
   )
 {
-  EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET    CommandPacket;
-  EDKII_PEI_NVM_EXPRESS_COMMAND                     Command;
-  EDKII_PEI_NVM_EXPRESS_COMPLETION                  Completion;
-  EFI_STATUS                                        Status;
-  NVME_ADMIN_CRIOCQ                                 CrIoCq;
+  EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  CommandPacket;
+  EFI_NVM_EXPRESS_COMMAND                   Command;
+  EFI_NVM_EXPRESS_COMPLETION                Completion;
+  EFI_STATUS                                Status;
+  NVME_ADMIN_CRIOCQ                         CrIoCq;
 
-  ZeroMem (&CommandPacket, sizeof(EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
-  ZeroMem (&Command, sizeof(EDKII_PEI_NVM_EXPRESS_COMMAND));
-  ZeroMem (&Completion, sizeof(EDKII_PEI_NVM_EXPRESS_COMPLETION));
-  ZeroMem (&CrIoCq, sizeof(NVME_ADMIN_CRIOCQ));
+  ZeroMem (&CommandPacket, sizeof (EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
+  ZeroMem (&Command, sizeof (EFI_NVM_EXPRESS_COMMAND));
+  ZeroMem (&Completion, sizeof (EFI_NVM_EXPRESS_COMPLETION));
+  ZeroMem (&CrIoCq, sizeof (NVME_ADMIN_CRIOCQ));
 
   CommandPacket.NvmeCmd        = &Command;
   CommandPacket.NvmeCompletion = &Completion;
 
-  Command.Cdw0.Opcode = NVME_ADMIN_CRIOCQ_CMD;
-  Command.Cdw0.Cid    = Private->Cid[NVME_ADMIN_QUEUE]++;
+  Command.Cdw0.Opcode          = NVME_ADMIN_CRIOCQ_CMD;
   CommandPacket.TransferBuffer = Private->CqBuffer[NVME_IO_QUEUE];
   CommandPacket.TransferLength = EFI_PAGE_SIZE;
   CommandPacket.CommandTimeout = NVME_GENERIC_TIMEOUT;
@@ -488,7 +482,7 @@ NvmeCreateIoCompletionQueue (
   CopyMem (&CommandPacket.NvmeCmd->Cdw10, &CrIoCq, sizeof (NVME_ADMIN_CRIOCQ));
   CommandPacket.NvmeCmd->Flags = CDW10_VALID | CDW11_VALID;
 
-  Status = NvmePassThru (
+  Status = NvmePassThruExecute (
              Private,
              NVME_CONTROLLER_NSID,
              &CommandPacket
@@ -507,25 +501,24 @@ NvmeCreateIoCompletionQueue (
 **/
 EFI_STATUS
 NvmeCreateIoSubmissionQueue (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private
   )
 {
-  EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET    CommandPacket;
-  EDKII_PEI_NVM_EXPRESS_COMMAND                     Command;
-  EDKII_PEI_NVM_EXPRESS_COMPLETION                  Completion;
-  EFI_STATUS                                        Status;
-  NVME_ADMIN_CRIOSQ                                 CrIoSq;
+  EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET  CommandPacket;
+  EFI_NVM_EXPRESS_COMMAND                   Command;
+  EFI_NVM_EXPRESS_COMPLETION                Completion;
+  EFI_STATUS                                Status;
+  NVME_ADMIN_CRIOSQ                         CrIoSq;
 
-  ZeroMem (&CommandPacket, sizeof(EDKII_PEI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
-  ZeroMem (&Command, sizeof(EDKII_PEI_NVM_EXPRESS_COMMAND));
-  ZeroMem (&Completion, sizeof(EDKII_PEI_NVM_EXPRESS_COMPLETION));
-  ZeroMem (&CrIoSq, sizeof(NVME_ADMIN_CRIOSQ));
+  ZeroMem (&CommandPacket, sizeof (EFI_NVM_EXPRESS_PASS_THRU_COMMAND_PACKET));
+  ZeroMem (&Command, sizeof (EFI_NVM_EXPRESS_COMMAND));
+  ZeroMem (&Completion, sizeof (EFI_NVM_EXPRESS_COMPLETION));
+  ZeroMem (&CrIoSq, sizeof (NVME_ADMIN_CRIOSQ));
 
   CommandPacket.NvmeCmd        = &Command;
   CommandPacket.NvmeCompletion = &Completion;
 
-  Command.Cdw0.Opcode = NVME_ADMIN_CRIOSQ_CMD;
-  Command.Cdw0.Cid    = Private->Cid[NVME_ADMIN_QUEUE]++;
+  Command.Cdw0.Opcode          = NVME_ADMIN_CRIOSQ_CMD;
   CommandPacket.TransferBuffer = Private->SqBuffer[NVME_IO_QUEUE];
   CommandPacket.TransferLength = EFI_PAGE_SIZE;
   CommandPacket.CommandTimeout = NVME_GENERIC_TIMEOUT;
@@ -539,7 +532,7 @@ NvmeCreateIoSubmissionQueue (
   CopyMem (&CommandPacket.NvmeCmd->Cdw10, &CrIoSq, sizeof (NVME_ADMIN_CRIOSQ));
   CommandPacket.NvmeCmd->Flags = CDW10_VALID | CDW11_VALID;
 
-  Status = NvmePassThru (
+  Status = NvmePassThruExecute (
              Private,
              NVME_CONTROLLER_NSID,
              &CommandPacket
@@ -558,15 +551,15 @@ NvmeCreateIoSubmissionQueue (
 **/
 EFI_STATUS
 NvmeControllerInit (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private
   )
 {
-  EFI_STATUS    Status;
-  UINTN         Index;
-  NVME_AQA      Aqa;
-  NVME_ASQ      Asq;
-  NVME_ACQ      Acq;
-  NVME_VER      Ver;
+  EFI_STATUS  Status;
+  UINTN       Index;
+  NVME_AQA    Aqa;
+  NVME_ASQ    Asq;
+  NVME_ACQ    Acq;
+  NVME_VER    Ver;
 
   //
   // Dump the NVME controller implementation version
@@ -578,7 +571,7 @@ NvmeControllerInit (
   // Read the controller Capabilities register and verify that the NVM command set is supported
   //
   NVME_GET_CAP (Private, &Private->Cap);
-  if (Private->Cap.Css != 0x01) {
+  if ((Private->Cap.Css & BIT0) == 0) {
     DEBUG ((DEBUG_ERROR, "%a: The NVME controller doesn't support NVMe command set.\n", __FUNCTION__));
     return EFI_UNSUPPORTED;
   }
@@ -598,6 +591,7 @@ NvmeControllerInit (
     ZeroMem ((VOID *)(UINTN)(&Private->SqTdbl[Index]), sizeof (NVME_SQTDBL));
     ZeroMem ((VOID *)(UINTN)(&Private->CqHdbl[Index]), sizeof (NVME_CQHDBL));
   }
+
   ZeroMem (Private->Buffer, EFI_PAGE_SIZE * NVME_MEM_MAX_PAGES);
 
   //
@@ -666,11 +660,13 @@ NvmeControllerInit (
       return EFI_OUT_OF_RESOURCES;
     }
   }
+
   Status = NvmeIdentifyController (Private, Private->ControllerData);
   if (EFI_ERROR (Status)) {
     DEBUG ((DEBUG_ERROR, "%a: NvmeIdentifyController fail, Status - %r\n", __FUNCTION__, Status));
     return Status;
   }
+
   NvmeDumpControllerData (Private->ControllerData);
 
   //
@@ -693,6 +689,7 @@ NvmeControllerInit (
     DEBUG ((DEBUG_ERROR, "%a: Create IO completion queue fail, Status - %r\n", __FUNCTION__, Status));
     return Status;
   }
+
   Status = NvmeCreateIoSubmissionQueue (Private);
   if (EFI_ERROR (Status)) {
     DEBUG ((DEBUG_ERROR, "%a: Create IO submission queue fail, Status - %r\n", __FUNCTION__, Status));
@@ -702,47 +699,25 @@ NvmeControllerInit (
 }
 
 /**
-  Free the resources allocated by an NVME controller.
+  Free the DMA resources allocated by an NVME controller.
 
   @param[in] Private     The pointer to the PEI_NVME_CONTROLLER_PRIVATE_DATA data structure.
 
 **/
 VOID
-NvmeFreeControllerResource (
-  IN PEI_NVME_CONTROLLER_PRIVATE_DATA    *Private
+NvmeFreeDmaResource (
+  IN PEI_NVME_CONTROLLER_PRIVATE_DATA  *Private
   )
 {
-  //
-  // Free the controller data buffer
-  //
-  if (Private->ControllerData != NULL) {
-    FreePool (Private->ControllerData);
-    Private->ControllerData = NULL;
-  }
+  ASSERT (Private != NULL);
 
-  //
-  // Free the DMA buffers
-  //
-  if (Private->Buffer != NULL) {
+  if (Private->BufferMapping != NULL) {
     IoMmuFreeBuffer (
-       NVME_MEM_MAX_PAGES,
-       Private->Buffer,
-       Private->BufferMapping
-       );
-    Private->Buffer = NULL;
+      NVME_MEM_MAX_PAGES,
+      Private->Buffer,
+      Private->BufferMapping
+      );
   }
 
-  //
-  // Free the namespaces information buffer
-  //
-  if (Private->NamespaceInfo != NULL) {
-    FreePool (Private->NamespaceInfo);
-    Private->NamespaceInfo = NULL;
-  }
-
-  //
-  // Free the controller private data structure
-  //
-  FreePool (Private);
   return;
 }
