@@ -3,13 +3,7 @@
 
   Copyright (c) 2009 - 2018, Intel Corporation. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -25,7 +19,6 @@ EFI_UDP6_PROTOCOL  mUdp6Protocol = {
   Udp6Poll
 };
 
-
 /**
   This function copies the current operational settings of this EFI UDPv6 Protocol
   instance into user-supplied buffers. This function is used optionally to retrieve
@@ -97,7 +90,6 @@ Udp6GetModeData (
   return Status;
 }
 
-
 /**
   This function is used to do the following:
   Initialize and start this instance of the EFI UDPv6 Protocol.
@@ -110,7 +102,7 @@ Udp6GetModeData (
 
   @retval EFI_SUCCESS            The configuration settings were set, changed, or
                                  reset successfully.
-  @retval EFI_NO_MAPPING         When the UdpConifgData.UseAnyStationAddress is set
+  @retval EFI_NO_MAPPING         When the UdpConfigData.UseAnyStationAddress is set
                                  to true and there is no address available for the IP6
                                  driver to bind a source address to this instance.
   @retval EFI_INVALID_PARAMETER  One or more following conditions are TRUE:
@@ -165,16 +157,16 @@ Udp6Configure (
   Status      = EFI_SUCCESS;
   ASSERT (Udp6Service != NULL);
 
-  OldTpl      = gBS->RaiseTPL (TPL_CALLBACK);
+  OldTpl = gBS->RaiseTPL (TPL_CALLBACK);
 
   if (UdpConfigData != NULL) {
-
     IP6_COPY_ADDRESS (&StationAddress, &UdpConfigData->StationAddress);
     IP6_COPY_ADDRESS (&RemoteAddress, &UdpConfigData->RemoteAddress);
 
     if ((!NetIp6IsUnspecifiedAddr (&StationAddress) && !NetIp6IsValidUnicast (&StationAddress)) ||
         (!NetIp6IsUnspecifiedAddr (&RemoteAddress) && !NetIp6IsValidUnicast (&RemoteAddress))
-        ){
+        )
+    {
       //
       // If not use default address, and StationAddress is not a valid unicast
       // if it is not IPv6 address or RemoteAddress is not a valid unicast IPv6
@@ -292,7 +284,6 @@ ON_EXIT:
   return Status;
 }
 
-
 /**
   This function is used to enable and disable the multicast group filtering.
 
@@ -354,12 +345,13 @@ Udp6Groups (
     if (McastIp != NULL) {
       FreePool (McastIp);
     }
+
     return EFI_NOT_STARTED;
   }
 
-  Ip      = Instance->IpInfo->Ip.Ip6;
+  Ip = Instance->IpInfo->Ip.Ip6;
 
-  OldTpl  = gBS->RaiseTPL (TPL_CALLBACK);
+  OldTpl = gBS->RaiseTPL (TPL_CALLBACK);
 
   //
   // Invoke the Ip instance the Udp6 instance consumes to do the group operation.
@@ -374,13 +366,11 @@ Udp6Groups (
   // Keep a local copy of the configured multicast IPs because IpIo receives
   // datagrams from the 0 station address IP instance and then UDP delivers to
   // the matched instance. This copy of multicast IPs is used to avoid receive
-  // the mutlicast datagrams destinated to multicast IPs the other instances configured.
+  // the multicast datagrams destinated to multicast IPs the other instances configured.
   //
   if (JoinFlag) {
-
-    Status = NetMapInsertTail (&Instance->McastIps, (VOID *) McastIp, NULL);
+    Status = NetMapInsertTail (&Instance->McastIps, (VOID *)McastIp, NULL);
   } else {
-
     Status = NetMapIterate (&Instance->McastIps, Udp6LeaveGroup, MulticastAddress);
     if ((MulticastAddress != NULL) && (Status == EFI_ABORTED)) {
       Status = EFI_SUCCESS;
@@ -400,8 +390,6 @@ ON_EXIT:
   return Status;
 }
 
-
-
 /**
   This function places a sending request to this instance of the EFI UDPv6 Protocol,
   alongside the transmit data that was filled by the user.
@@ -429,13 +417,13 @@ ON_EXIT:
                                  One or more of the
                                  Token.Packet.TxData.FragmentTable[].FragmentBuffer
                                  fields is NULL. One or more of the
-                                 Token.Packet.TxData.UdpSessionData.DestinationAddres
+                                 Token.Packet.TxData.UdpSessionData.DestinationAddress
                                  are not valid unicast IPv6
                                  addresses if the  UdpSessionData is not NULL.
                                  Token.Packet.TxData.UdpSessionData.
                                  DestinationAddress is NULL
                                  Token.Packet.TxData.UdpSessionData.
-                                 DestinatioPort
+                                 DestinationPort
                                  is zero.
                                  Token.Packet.TxData.UdpSessionData is NULL and this
                                  instance's UdpConfigData.RemoteAddress  is unspecified.
@@ -496,7 +484,8 @@ Udp6Transmit (
 
   if (EFI_ERROR (NetMapIterate (&Instance->TxTokens, Udp6TokenExist, Token)) ||
       EFI_ERROR (NetMapIterate (&Instance->RxTokens, Udp6TokenExist, Token))
-      ){
+      )
+  {
     //
     // Try to find a duplicate token in the two token maps, if found, return
     // EFI_ACCESS_DENIED.
@@ -511,7 +500,7 @@ Udp6Transmit (
   // Create a net buffer to hold the user buffer and the udp header.
   //
   Packet = NetbufFromExt (
-             (NET_FRAGMENT *) TxData->FragmentTable,
+             (NET_FRAGMENT *)TxData->FragmentTable,
              TxData->FragmentCount,
              UDP6_HEADER_SIZE,
              0,
@@ -526,10 +515,10 @@ Udp6Transmit (
   //
   // Store the IpIo in ProtoData.
   //
-  Udp6Service                        = Instance->Udp6Service;
-  *((UINTN *) &Packet->ProtoData[0]) = (UINTN) (Udp6Service->IpIo);
+  Udp6Service                       = Instance->Udp6Service;
+  *((UINTN *)&Packet->ProtoData[0]) = (UINTN)(Udp6Service->IpIo);
 
-  Udp6Header = (EFI_UDP_HEADER *) NetbufAllocSpace (Packet, UDP6_HEADER_SIZE, TRUE);
+  Udp6Header = (EFI_UDP_HEADER *)NetbufAllocSpace (Packet, UDP6_HEADER_SIZE, TRUE);
   ASSERT (Udp6Header != NULL);
   if (Udp6Header == NULL) {
     Status = EFI_OUT_OF_RESOURCES;
@@ -541,10 +530,10 @@ Udp6Transmit (
   //
   // Fill the udp header.
   //
-  Udp6Header->SrcPort      = HTONS (ConfigData->StationPort);
-  Udp6Header->DstPort      = HTONS (ConfigData->RemotePort);
-  Udp6Header->Length       = HTONS ((UINT16) Packet->TotalSize);
-  Udp6Header->Checksum     = 0;
+  Udp6Header->SrcPort  = HTONS (ConfigData->StationPort);
+  Udp6Header->DstPort  = HTONS (ConfigData->RemotePort);
+  Udp6Header->Length   = HTONS ((UINT16)Packet->TotalSize);
+  Udp6Header->Checksum = 0;
   //
   // Set the UDP Header in NET_BUF, this UDP header is for IP6 can fast get the
   // Udp header for pseudoHeadCheckSum.
@@ -570,7 +559,7 @@ Udp6Transmit (
     }
 
     //
-    //Calculate the pseudo head checksum using the overridden parameters.
+    // Calculate the pseudo head checksum using the overridden parameters.
     //
     if (!NetIp6IsUnspecifiedAddr (&ConfigData->StationAddress)) {
       HeadSum = NetIp6PseudoHeadChecksum (
@@ -592,11 +581,10 @@ Udp6Transmit (
       }
     } else {
       //
-      // Set the checksum is zero if the ConfigData->StationAddress is unspcified
+      // Set the checksum is zero if the ConfigData->StationAddress is unspecified
       // and the Ipv6 will fill the correct value of this checksum.
       //
       Udp6Header->Checksum = 0;
-
     }
   } else {
     //
@@ -617,8 +605,6 @@ Udp6Transmit (
     }
   }
 
-
-
   //
   // Fill the IpIo Override data.
   //
@@ -637,7 +623,7 @@ Udp6Transmit (
   //
   // Send out this datagram through IpIo.
   //
-  if (UdpSessionData != NULL){
+  if (UdpSessionData != NULL) {
     IP6_COPY_ADDRESS (&(IpDestAddr.v6), &Destination);
   } else {
     ZeroMem (&IpDestAddr.v6, sizeof (EFI_IPv6_ADDRESS));
@@ -670,7 +656,6 @@ ON_EXIT:
   return Status;
 }
 
-
 /**
   This function places a completion token into the receive packet queue. This function
   is always asynchronous.
@@ -723,7 +708,8 @@ Udp6Receive (
 
   if (EFI_ERROR (NetMapIterate (&Instance->RxTokens, Udp6TokenExist, Token)) ||
       EFI_ERROR (NetMapIterate (&Instance->TxTokens, Udp6TokenExist, Token))
-      ){
+      )
+  {
     //
     // Return EFI_ACCESS_DENIED if the specified token is already in the TxTokens or
     // RxTokens map.
@@ -765,7 +751,6 @@ ON_EXIT:
   return Status;
 }
 
-
 /**
   This function is used to abort a pending transmit or receive request.
 
@@ -813,7 +798,7 @@ Udp6Cancel (
   OldTpl = gBS->RaiseTPL (TPL_CALLBACK);
 
   //
-  // Cancle the tokens specified by Token for this instance.
+  // Cancel the tokens specified by Token for this instance.
   //
   Status = Udp6InstanceCancelToken (Instance, Token);
 
@@ -827,7 +812,6 @@ Udp6Cancel (
   return Status;
 }
 
-
 /**
   This function can be used by network drivers and applications to increase the rate that
   data packets are moved between the communications device and the transmit/receive queues.
