@@ -556,6 +556,7 @@ GetResourcePadding (
   EFI_PCI_ROOT_BRIDGE_IO_PROTOCOL_PCI_ADDRESS      *Address;
   BOOLEAN                                          DefaultIo;
   BOOLEAN                                          DefaultMmio;
+  BOOLEAN                                          DefaultPrefMmio;
   RESOURCE_PADDING                                 ReservationRequest;
   EFI_ACPI_ADDRESS_SPACE_DESCRIPTOR                *FirstResource;
   EFI_STATUS                                       ReservationHintStatus;
@@ -588,8 +589,9 @@ GetResourcePadding (
     return EFI_INVALID_PARAMETER;
   }
 
-  DefaultIo   = TRUE;
-  DefaultMmio = TRUE;
+  DefaultIo       = TRUE;
+  DefaultMmio     = TRUE;
+  DefaultPrefMmio = TRUE;
 
   //
   // Init ReservationRequest, and point FirstResource one past the last
@@ -722,6 +724,7 @@ GetResourcePadding (
       HighBit = HighBitSetRoundUp32 (ReservationHint.Prefetchable32BitMmio);
       if (HighBit != -1) {
         SetMmioPadding (--FirstResource, TRUE, TRUE, (UINTN)HighBit);
+        DefaultPrefMmio = FALSE;
       }
     } else if ((ReservationHint.Prefetchable64BitMmio > 0) &&
                (ReservationHint.Prefetchable64BitMmio < MAX_UINT64))
@@ -729,6 +732,7 @@ GetResourcePadding (
       HighBit = HighBitSetRoundUp64 (ReservationHint.Prefetchable64BitMmio);
       if (HighBit != -1) {
         SetMmioPadding (--FirstResource, TRUE, FALSE, (UINTN)HighBit);
+        DefaultPrefMmio = FALSE;
       }
     }
   }
@@ -752,6 +756,19 @@ GetResourcePadding (
       );
   }
 
+  if (DefaultPrefMmio) {
+    UINT64  Pci64Size = PcdGet64 (PcdPciMmio64Size);
+
+    if (Pci64Size > SIZE_32GB) {
+      SetMmioPadding (
+        --FirstResource,
+        TRUE,
+        FALSE,
+        (UINTN)HighBitSetRoundUp64 (RShiftU64 (Pci64Size, 8))
+        );
+    }
+  }
+
   //
   // Output a copy of ReservationRequest from the lowest-address populated
   // entry until the end of the structure (including
