@@ -4,13 +4,7 @@
 
 Copyright (c) 2015 - 2018, Intel Corporation. All rights reserved.<BR>
 (C) Copyright 2018 Hewlett Packard Enterprise Development LP<BR>
-This program and the accompanying materials
-are licensed and made available under the terms and conditions of the BSD License
-which accompanies this distribution.  The full text of the license may be found at
-http://opensource.org/licenses/bsd-license.php
-
-THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -24,12 +18,12 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
 
 #include <IndustryStandard/TpmPtp.h>
 
-#define EFI_TCG2_EVENT_LOG_FORMAT_ALL   (EFI_TCG2_EVENT_LOG_FORMAT_TCG_1_2 | EFI_TCG2_EVENT_LOG_FORMAT_TCG_2)
+#define EFI_TCG2_EVENT_LOG_FORMAT_ALL  (EFI_TCG2_EVENT_LOG_FORMAT_TCG_1_2 | EFI_TCG2_EVENT_LOG_FORMAT_TCG_2)
 
 TPM_INSTANCE_ID  mTpmInstanceId[TPM_DEVICE_MAX + 1] = TPM_INSTANCE_ID_LIST;
 
-TCG2_CONFIG_PRIVATE_DATA         *mTcg2ConfigPrivateDate;
-TCG2_CONFIG_PRIVATE_DATA         mTcg2ConfigPrivateDateTemplate = {
+TCG2_CONFIG_PRIVATE_DATA  *mTcg2ConfigPrivateDate;
+TCG2_CONFIG_PRIVATE_DATA  mTcg2ConfigPrivateDateTemplate = {
   TCG2_CONFIG_PRIVATE_DATA_SIGNATURE,
   {
     Tcg2ExtractConfig,
@@ -38,14 +32,14 @@ TCG2_CONFIG_PRIVATE_DATA         mTcg2ConfigPrivateDateTemplate = {
   }
 };
 
-HII_VENDOR_DEVICE_PATH          mTcg2HiiVendorDevicePath = {
+HII_VENDOR_DEVICE_PATH  mTcg2HiiVendorDevicePath = {
   {
     {
       HARDWARE_DEVICE_PATH,
       HW_VENDOR_DP,
       {
-        (UINT8) (sizeof (VENDOR_DEVICE_PATH)),
-        (UINT8) ((sizeof (VENDOR_DEVICE_PATH)) >> 8)
+        (UINT8)(sizeof (VENDOR_DEVICE_PATH)),
+        (UINT8)((sizeof (VENDOR_DEVICE_PATH)) >> 8)
       }
     },
     TCG2_CONFIG_FORM_SET_GUID
@@ -54,8 +48,8 @@ HII_VENDOR_DEVICE_PATH          mTcg2HiiVendorDevicePath = {
     END_DEVICE_PATH_TYPE,
     END_ENTIRE_DEVICE_PATH_SUBTYPE,
     {
-      (UINT8) (END_DEVICE_PATH_LENGTH),
-      (UINT8) ((END_DEVICE_PATH_LENGTH) >> 8)
+      (UINT8)(END_DEVICE_PATH_LENGTH),
+      (UINT8)((END_DEVICE_PATH_LENGTH) >> 8)
     }
   }
 };
@@ -72,7 +66,7 @@ UINT8  mCurrentPpRequest;
 **/
 BOOLEAN
 IsPtpCrbSupported (
-  IN VOID                 *Register
+  IN VOID  *Register
   )
 {
   PTP_CRB_INTERFACE_IDENTIFIER  InterfaceId;
@@ -84,9 +78,11 @@ IsPtpCrbSupported (
 
   if (((InterfaceId.Bits.InterfaceType == PTP_INTERFACE_IDENTIFIER_INTERFACE_TYPE_CRB) ||
        (InterfaceId.Bits.InterfaceType == PTP_INTERFACE_IDENTIFIER_INTERFACE_TYPE_FIFO)) &&
-      (InterfaceId.Bits.CapCRB != 0)) {
+      (InterfaceId.Bits.CapCRB != 0))
+  {
     return TRUE;
   }
+
   return FALSE;
 }
 
@@ -100,7 +96,7 @@ IsPtpCrbSupported (
 **/
 BOOLEAN
 IsPtpFifoSupported (
-  IN VOID                 *Register
+  IN VOID  *Register
   )
 {
   PTP_CRB_INTERFACE_IDENTIFIER  InterfaceId;
@@ -112,9 +108,11 @@ IsPtpFifoSupported (
 
   if (((InterfaceId.Bits.InterfaceType == PTP_INTERFACE_IDENTIFIER_INTERFACE_TYPE_CRB) ||
        (InterfaceId.Bits.InterfaceType == PTP_INTERFACE_IDENTIFIER_INTERFACE_TYPE_FIFO)) &&
-      (InterfaceId.Bits.CapFIFO != 0)) {
+      (InterfaceId.Bits.CapFIFO != 0))
+  {
     return TRUE;
   }
+
   return FALSE;
 }
 
@@ -132,40 +130,44 @@ IsPtpFifoSupported (
 **/
 EFI_STATUS
 SetPtpInterface (
-  IN VOID                 *Register,
-  IN UINT8                PtpInterface
+  IN VOID   *Register,
+  IN UINT8  PtpInterface
   )
 {
   TPM2_PTP_INTERFACE_TYPE       PtpInterfaceCurrent;
   PTP_CRB_INTERFACE_IDENTIFIER  InterfaceId;
 
-  PtpInterfaceCurrent = PcdGet8(PcdActiveTpmInterfaceType);
+  PtpInterfaceCurrent = PcdGet8 (PcdActiveTpmInterfaceType);
   if ((PtpInterfaceCurrent != Tpm2PtpInterfaceFifo) &&
-      (PtpInterfaceCurrent != Tpm2PtpInterfaceCrb)) {
+      (PtpInterfaceCurrent != Tpm2PtpInterfaceCrb))
+  {
     return EFI_UNSUPPORTED;
   }
+
   InterfaceId.Uint32 = MmioRead32 ((UINTN)&((PTP_CRB_REGISTERS *)Register)->InterfaceId);
   if (InterfaceId.Bits.IntfSelLock != 0) {
     return EFI_WRITE_PROTECTED;
   }
 
   switch (PtpInterface) {
-  case Tpm2PtpInterfaceFifo:
-    if (InterfaceId.Bits.CapFIFO == 0) {
-      return EFI_UNSUPPORTED;
-    }
-    InterfaceId.Bits.InterfaceSelector = PTP_INTERFACE_IDENTIFIER_INTERFACE_SELECTOR_FIFO;
-    MmioWrite32 ((UINTN)&((PTP_CRB_REGISTERS *)Register)->InterfaceId, InterfaceId.Uint32);
-    return EFI_SUCCESS;
-  case Tpm2PtpInterfaceCrb:
-    if (InterfaceId.Bits.CapCRB == 0) {
-      return EFI_UNSUPPORTED;
-    }
-    InterfaceId.Bits.InterfaceSelector = PTP_INTERFACE_IDENTIFIER_INTERFACE_SELECTOR_CRB;
-    MmioWrite32 ((UINTN)&((PTP_CRB_REGISTERS *)Register)->InterfaceId, InterfaceId.Uint32);
-    return EFI_SUCCESS;
-  default:
-    return EFI_INVALID_PARAMETER;
+    case Tpm2PtpInterfaceFifo:
+      if (InterfaceId.Bits.CapFIFO == 0) {
+        return EFI_UNSUPPORTED;
+      }
+
+      InterfaceId.Bits.InterfaceSelector = PTP_INTERFACE_IDENTIFIER_INTERFACE_SELECTOR_FIFO;
+      MmioWrite32 ((UINTN)&((PTP_CRB_REGISTERS *)Register)->InterfaceId, InterfaceId.Uint32);
+      return EFI_SUCCESS;
+    case Tpm2PtpInterfaceCrb:
+      if (InterfaceId.Bits.CapCRB == 0) {
+        return EFI_UNSUPPORTED;
+      }
+
+      InterfaceId.Bits.InterfaceSelector = PTP_INTERFACE_IDENTIFIER_INTERFACE_SELECTOR_CRB;
+      MmioWrite32 ((UINTN)&((PTP_CRB_REGISTERS *)Register)->InterfaceId, InterfaceId.Uint32);
+      return EFI_SUCCESS;
+    default:
+      return EFI_INVALID_PARAMETER;
   }
 }
 
@@ -198,13 +200,13 @@ SetPtpInterface (
 EFI_STATUS
 EFIAPI
 Tcg2ExtractConfig (
-  IN CONST EFI_HII_CONFIG_ACCESS_PROTOCOL        *This,
-  IN CONST EFI_STRING                            Request,
-       OUT EFI_STRING                            *Progress,
-       OUT EFI_STRING                            *Results
+  IN CONST EFI_HII_CONFIG_ACCESS_PROTOCOL  *This,
+  IN CONST EFI_STRING                      Request,
+  OUT EFI_STRING                           *Progress,
+  OUT EFI_STRING                           *Results
   )
 {
-  if (Progress == NULL || Results == NULL) {
+  if ((Progress == NULL) || (Results == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -223,7 +225,7 @@ Tcg2ExtractConfig (
 **/
 EFI_STATUS
 SaveTcg2PpRequest (
-  IN UINT8                         PpRequest
+  IN UINT8  PpRequest
   )
 {
   UINT32      ReturnCode;
@@ -232,7 +234,7 @@ SaveTcg2PpRequest (
   ReturnCode = Tcg2PhysicalPresenceLibSubmitRequestToPreOSFunction (PpRequest, 0);
   if (ReturnCode == TCG_PP_SUBMIT_REQUEST_TO_PREOS_SUCCESS) {
     mCurrentPpRequest = PpRequest;
-    Status = EFI_SUCCESS;
+    Status            = EFI_SUCCESS;
   } else if (ReturnCode == TCG_PP_SUBMIT_REQUEST_TO_PREOS_GENERAL_FAILURE) {
     Status = EFI_OUT_OF_RESOURCES;
   } else if (ReturnCode == TCG_PP_SUBMIT_REQUEST_TO_PREOS_NOT_IMPLEMENTED) {
@@ -255,7 +257,7 @@ SaveTcg2PpRequest (
 **/
 EFI_STATUS
 SaveTcg2PpRequestParameter (
-  IN UINT32                        PpRequestParameter
+  IN UINT32  PpRequestParameter
   )
 {
   UINT32      ReturnCode;
@@ -287,8 +289,8 @@ SaveTcg2PpRequestParameter (
 **/
 EFI_STATUS
 SaveTcg2PCRBanksRequest (
-  IN UINTN   PCRBankIndex,
-  IN BOOLEAN Enable
+  IN UINTN    PCRBankIndex,
+  IN BOOLEAN  Enable
   )
 {
   UINT32      ReturnCode;
@@ -335,12 +337,12 @@ SaveTcg2PCRBanksRequest (
 EFI_STATUS
 EFIAPI
 Tcg2RouteConfig (
-  IN CONST EFI_HII_CONFIG_ACCESS_PROTOCOL      *This,
-  IN CONST EFI_STRING                          Configuration,
-       OUT EFI_STRING                          *Progress
+  IN CONST EFI_HII_CONFIG_ACCESS_PROTOCOL  *This,
+  IN CONST EFI_STRING                      Configuration,
+  OUT EFI_STRING                           *Progress
   )
 {
-  if (Configuration == NULL || Progress == NULL) {
+  if ((Configuration == NULL) || (Progress == NULL)) {
     return EFI_INVALID_PARAMETER;
   }
 
@@ -359,9 +361,9 @@ Tcg2RouteConfig (
 
 **/
 EFI_STATUS
-GetTpm2HID(
-   CHAR8 *Hid,
-   UINTN  Size
+GetTpm2HID (
+  CHAR8  *Hid,
+  UINTN  Size
   )
 {
   EFI_STATUS  Status;
@@ -372,54 +374,53 @@ GetTpm2HID(
 
   PnpHID = TRUE;
 
-  ZeroMem(Hid, Size);
+  ZeroMem (Hid, Size);
 
   //
   // Get Manufacturer ID
   //
-  Status = Tpm2GetCapabilityManufactureID(&ManufacturerID);
-  if (!EFI_ERROR(Status)) {
-    DEBUG((DEBUG_INFO, "TPM_PT_MANUFACTURER 0x%08x\n", ManufacturerID));
+  Status = Tpm2GetCapabilityManufactureID (&ManufacturerID);
+  if (!EFI_ERROR (Status)) {
+    DEBUG ((DEBUG_INFO, "TPM_PT_MANUFACTURER 0x%08x\n", ManufacturerID));
     //
     // ManufacturerID defined in TCG Vendor ID Registry
     // may tailed with 0x00 or 0x20
     //
-    if ((ManufacturerID >> 24) == 0x00 || ((ManufacturerID >> 24) == 0x20)) {
+    if (((ManufacturerID >> 24) == 0x00) || ((ManufacturerID >> 24) == 0x20)) {
       //
       //  HID containing PNP ID "NNN####"
       //   NNN is uppercase letter for Vendor ID specified by manufacturer
       //
-      CopyMem(Hid, &ManufacturerID, 3);
+      CopyMem (Hid, &ManufacturerID, 3);
     } else {
       //
       //  HID containing ACP ID "NNNN####"
       //   NNNN is uppercase letter for Vendor ID specified by manufacturer
       //
-      CopyMem(Hid, &ManufacturerID, 4);
+      CopyMem (Hid, &ManufacturerID, 4);
       PnpHID = FALSE;
     }
   } else {
     DEBUG ((DEBUG_ERROR, "Get TPM_PT_MANUFACTURER failed %x!\n", Status));
-    ASSERT(FALSE);
+    ASSERT (FALSE);
     return Status;
   }
 
-  Status = Tpm2GetCapabilityFirmwareVersion(&FirmwareVersion1, &FirmwareVersion2);
-  if (!EFI_ERROR(Status)) {
-    DEBUG((DEBUG_INFO, "TPM_PT_FIRMWARE_VERSION_1 0x%x\n", FirmwareVersion1));
-    DEBUG((DEBUG_INFO, "TPM_PT_FIRMWARE_VERSION_2 0x%x\n", FirmwareVersion2));
+  Status = Tpm2GetCapabilityFirmwareVersion (&FirmwareVersion1, &FirmwareVersion2);
+  if (!EFI_ERROR (Status)) {
+    DEBUG ((DEBUG_INFO, "TPM_PT_FIRMWARE_VERSION_1 0x%x\n", FirmwareVersion1));
+    DEBUG ((DEBUG_INFO, "TPM_PT_FIRMWARE_VERSION_2 0x%x\n", FirmwareVersion2));
     //
     //   #### is Firmware Version 1
     //
     if (PnpHID) {
-      AsciiSPrint(Hid + 3, TPM_HID_PNP_SIZE - 3, "%02d%02d", ((FirmwareVersion1 & 0xFFFF0000) >> 16), (FirmwareVersion1 & 0x0000FFFF));
+      AsciiSPrint (Hid + 3, TPM_HID_PNP_SIZE - 3, "%02d%02d", ((FirmwareVersion1 & 0xFFFF0000) >> 16), (FirmwareVersion1 & 0x0000FFFF));
     } else {
-      AsciiSPrint(Hid + 4, TPM_HID_ACPI_SIZE - 4, "%02d%02d", ((FirmwareVersion1 & 0xFFFF0000) >> 16), (FirmwareVersion1 & 0x0000FFFF));
+      AsciiSPrint (Hid + 4, TPM_HID_ACPI_SIZE - 4, "%02d%02d", ((FirmwareVersion1 & 0xFFFF0000) >> 16), (FirmwareVersion1 & 0x0000FFFF));
     }
-
   } else {
     DEBUG ((DEBUG_ERROR, "Get TPM_PT_FIRMWARE_VERSION_X failed %x!\n", Status));
-    ASSERT(FALSE);
+    ASSERT (FALSE);
     return Status;
   }
 
@@ -444,15 +445,15 @@ GetTpm2HID(
 **/
 EFI_STATUS
 Tcg2VersionInfoCallback (
-  IN EFI_BROWSER_ACTION         Action,
-  IN EFI_QUESTION_ID            QuestionId,
-  IN UINT8                      Type,
-  IN EFI_IFR_TYPE_VALUE         *Value
+  IN EFI_BROWSER_ACTION  Action,
+  IN EFI_QUESTION_ID     QuestionId,
+  IN UINT8               Type,
+  IN EFI_IFR_TYPE_VALUE  *Value
   )
 {
-  EFI_INPUT_KEY                 Key;
-  UINT64                        PcdTcg2PpiVersion;
-  UINT8                         PcdTpm2AcpiTableRev;
+  EFI_INPUT_KEY  Key;
+  UINT64         PcdTcg2PpiVersion;
+  UINT8          PcdTpm2AcpiTableRev;
 
   ASSERT (Action == EFI_BROWSER_ACTION_SUBMITTED);
 
@@ -467,7 +468,7 @@ Tcg2VersionInfoCallback (
     CopyMem (
       &PcdTcg2PpiVersion,
       PcdGetPtr (PcdTcgPhysicalPresenceInterfaceVer),
-      AsciiStrSize ((CHAR8 *) PcdGetPtr (PcdTcgPhysicalPresenceInterfaceVer))
+      AsciiStrSize ((CHAR8 *)PcdGetPtr (PcdTcgPhysicalPresenceInterfaceVer))
       );
     if (PcdTcg2PpiVersion != Value->u64) {
       CreatePopUp (
@@ -478,7 +479,7 @@ Tcg2VersionInfoCallback (
         NULL
         );
     }
-  } else if (QuestionId == KEY_TPM2_ACPI_REVISION){
+  } else if (QuestionId == KEY_TPM2_ACPI_REVISION) {
     //
     // Get the PCD value after EFI_BROWSER_ACTION_SUBMITTED,
     // the SetVariable to TCG2_VERSION_NAME should have been done.
@@ -526,19 +527,19 @@ Tcg2VersionInfoCallback (
 EFI_STATUS
 EFIAPI
 Tcg2Callback (
-  IN CONST EFI_HII_CONFIG_ACCESS_PROTOCOL      *This,
-  IN     EFI_BROWSER_ACTION                    Action,
-  IN     EFI_QUESTION_ID                       QuestionId,
-  IN     UINT8                                 Type,
-  IN     EFI_IFR_TYPE_VALUE                    *Value,
-     OUT EFI_BROWSER_ACTION_REQUEST            *ActionRequest
+  IN CONST EFI_HII_CONFIG_ACCESS_PROTOCOL  *This,
+  IN     EFI_BROWSER_ACTION                Action,
+  IN     EFI_QUESTION_ID                   QuestionId,
+  IN     UINT8                             Type,
+  IN     EFI_IFR_TYPE_VALUE                *Value,
+  OUT EFI_BROWSER_ACTION_REQUEST           *ActionRequest
   )
 {
-  EFI_STATUS                 Status;
-  EFI_INPUT_KEY              Key;
-  CHAR8                      HidStr[16];
-  CHAR16                     UnHidStr[16];
-  TCG2_CONFIG_PRIVATE_DATA   *Private;
+  EFI_STATUS                Status;
+  EFI_INPUT_KEY             Key;
+  CHAR8                     HidStr[16];
+  CHAR16                    UnHidStr[16];
+  TCG2_CONFIG_PRIVATE_DATA  *Private;
 
   if ((This == NULL) || (Value == NULL) || (ActionRequest == NULL)) {
     return EFI_INVALID_PARAMETER;
@@ -551,24 +552,25 @@ Tcg2Callback (
     // Update TPM2 HID info
     //
     if (QuestionId == KEY_TPM_DEVICE) {
-      Status = GetTpm2HID(HidStr, 16);
+      Status = GetTpm2HID (HidStr, 16);
 
-      if (EFI_ERROR(Status)) {
+      if (EFI_ERROR (Status)) {
         //
         //  Fail to get TPM2 HID
         //
         HiiSetString (Private->HiiHandle, STRING_TOKEN (STR_TPM2_ACPI_HID_CONTENT), L"Unknown", NULL);
       } else {
-        AsciiStrToUnicodeStrS(HidStr, UnHidStr, 16);
+        AsciiStrToUnicodeStrS (HidStr, UnHidStr, 16);
         HiiSetString (Private->HiiHandle, STRING_TOKEN (STR_TPM2_ACPI_HID_CONTENT), UnHidStr, NULL);
       }
     }
+
     return EFI_SUCCESS;
   }
 
   if (Action == EFI_BROWSER_ACTION_CHANGING) {
     if (QuestionId == KEY_TPM_DEVICE_INTERFACE) {
-      Status = SetPtpInterface ((VOID *) (UINTN) PcdGet64 (PcdTpmBaseAddress), Value->u8);
+      Status = SetPtpInterface ((VOID *)(UINTN)PcdGet64 (PcdTpmBaseAddress), Value->u8);
       if (EFI_ERROR (Status)) {
         CreatePopUp (
           EFI_LIGHTGRAY | EFI_BACKGROUND_BLUE,
@@ -585,19 +587,22 @@ Tcg2Callback (
     if (QuestionId == KEY_TPM_DEVICE) {
       return EFI_SUCCESS;
     }
+
     if (QuestionId == KEY_TPM2_OPERATION) {
       return SaveTcg2PpRequest (Value->u8);
     }
+
     if (QuestionId == KEY_TPM2_OPERATION_PARAMETER) {
       return SaveTcg2PpRequestParameter (Value->u32);
     }
+
     if ((QuestionId >= KEY_TPM2_PCR_BANKS_REQUEST_0) && (QuestionId <= KEY_TPM2_PCR_BANKS_REQUEST_4)) {
       return SaveTcg2PCRBanksRequest (QuestionId - KEY_TPM2_PCR_BANKS_REQUEST_0, Value->b);
     }
   }
 
   if (Action == EFI_BROWSER_ACTION_SUBMITTED) {
-    if (QuestionId == KEY_TCG2_PPI_VERSION || QuestionId == KEY_TPM2_ACPI_REVISION) {
+    if ((QuestionId == KEY_TCG2_PPI_VERSION) || (QuestionId == KEY_TPM2_ACPI_REVISION)) {
       return Tcg2VersionInfoCallback (Action, QuestionId, Type, Value);
     }
   }
@@ -621,36 +626,41 @@ AppendBufferWithTpmAlgHash (
   )
 {
   switch (TpmAlgHash) {
-  case TPM_ALG_SHA1:
-    if (Buffer[0] != 0) {
-      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
-    }
-    StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA1");
-    break;
-  case TPM_ALG_SHA256:
-    if (Buffer[0] != 0) {
-      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
-    }
-    StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA256");
-    break;
-  case TPM_ALG_SHA384:
-    if (Buffer[0] != 0) {
-      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
-    }
-    StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA384");
-    break;
-  case TPM_ALG_SHA512:
-    if (Buffer[0] != 0) {
-      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
-    }
-    StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA512");
-    break;
-  case TPM_ALG_SM3_256:
-    if (Buffer[0] != 0) {
-      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
-    }
-    StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SM3_256");
-    break;
+    case TPM_ALG_SHA1:
+      if (Buffer[0] != 0) {
+        StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
+      }
+
+      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA1");
+      break;
+    case TPM_ALG_SHA256:
+      if (Buffer[0] != 0) {
+        StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
+      }
+
+      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA256");
+      break;
+    case TPM_ALG_SHA384:
+      if (Buffer[0] != 0) {
+        StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
+      }
+
+      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA384");
+      break;
+    case TPM_ALG_SHA512:
+      if (Buffer[0] != 0) {
+        StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
+      }
+
+      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA512");
+      break;
+    case TPM_ALG_SM3_256:
+      if (Buffer[0] != 0) {
+        StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
+      }
+
+      StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SM3_256");
+      break;
   }
 }
 
@@ -674,30 +684,39 @@ FillBufferWithBootHashAlg (
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA1");
   }
+
   if ((BootHashAlg & EFI_TCG2_BOOT_HASH_ALG_SHA256) != 0) {
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA256");
   }
+
   if ((BootHashAlg & EFI_TCG2_BOOT_HASH_ALG_SHA384) != 0) {
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA384");
   }
+
   if ((BootHashAlg & EFI_TCG2_BOOT_HASH_ALG_SHA512) != 0) {
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SHA512");
   }
+
   if ((BootHashAlg & EFI_TCG2_BOOT_HASH_ALG_SM3_256) != 0) {
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"SM3_256");
   }
 }
@@ -711,26 +730,26 @@ FillBufferWithBootHashAlg (
 **/
 VOID
 SetConfigInfo (
-  IN OUT TCG2_CONFIGURATION_INFO         *Tcg2ConfigInfo,
-  IN UINT32                              TpmAlgHash
+  IN OUT TCG2_CONFIGURATION_INFO  *Tcg2ConfigInfo,
+  IN UINT32                       TpmAlgHash
   )
 {
   switch (TpmAlgHash) {
-  case TPM_ALG_SHA1:
-    Tcg2ConfigInfo->Sha1Supported = TRUE;
-    break;
-  case TPM_ALG_SHA256:
-    Tcg2ConfigInfo->Sha256Supported = TRUE;
-    break;
-  case TPM_ALG_SHA384:
-    Tcg2ConfigInfo->Sha384Supported = TRUE;
-    break;
-  case TPM_ALG_SHA512:
-    Tcg2ConfigInfo->Sha512Supported = TRUE;
-    break;
-  case TPM_ALG_SM3_256:
-    Tcg2ConfigInfo->Sm3Supported = TRUE;
-    break;
+    case TPM_ALG_SHA1:
+      Tcg2ConfigInfo->Sha1Supported = TRUE;
+      break;
+    case TPM_ALG_SHA256:
+      Tcg2ConfigInfo->Sha256Supported = TRUE;
+      break;
+    case TPM_ALG_SHA384:
+      Tcg2ConfigInfo->Sha384Supported = TRUE;
+      break;
+    case TPM_ALG_SHA512:
+      Tcg2ConfigInfo->Sha512Supported = TRUE;
+      break;
+    case TPM_ALG_SM3_256:
+      Tcg2ConfigInfo->Sm3Supported = TRUE;
+      break;
   }
 }
 
@@ -754,18 +773,23 @@ FillBufferWithTCG2EventLogFormat (
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"TCG_1_2");
   }
+
   if ((TCG2EventLogFormat & EFI_TCG2_EVENT_LOG_FORMAT_TCG_2) != 0) {
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"TCG_2");
   }
+
   if ((TCG2EventLogFormat & (~EFI_TCG2_EVENT_LOG_FORMAT_ALL)) != 0) {
     if (Buffer[0] != 0) {
       StrCatS (Buffer, BufferSize / sizeof (CHAR16), L", ");
     }
+
     StrCatS (Buffer, BufferSize / sizeof (CHAR16), L"UNKNOWN");
   }
 }
@@ -794,17 +818,18 @@ InstallTcg2ConfigForm (
   CHAR16                          TempBuffer[1024];
   TCG2_CONFIGURATION_INFO         Tcg2ConfigInfo;
   TPM2_PTP_INTERFACE_TYPE         TpmDeviceInterfaceDetected;
+  BOOLEAN                         IsCmdImp = FALSE;
 
   DriverHandle = NULL;
   ConfigAccess = &PrivateData->ConfigAccess;
-  Status = gBS->InstallMultipleProtocolInterfaces (
-                  &DriverHandle,
-                  &gEfiDevicePathProtocolGuid,
-                  &mTcg2HiiVendorDevicePath,
-                  &gEfiHiiConfigAccessProtocolGuid,
-                  ConfigAccess,
-                  NULL
-                  );
+  Status       = gBS->InstallMultipleProtocolInterfaces (
+                        &DriverHandle,
+                        &gEfiDevicePathProtocolGuid,
+                        &mTcg2HiiVendorDevicePath,
+                        &gEfiHiiConfigAccessProtocolGuid,
+                        ConfigAccess,
+                        NULL
+                        );
   if (EFI_ERROR (Status)) {
     return Status;
   }
@@ -840,21 +865,21 @@ InstallTcg2ConfigForm (
   // Update static data
   //
   switch (PrivateData->TpmDeviceDetected) {
-  case TPM_DEVICE_NULL:
-    HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"Not Found", NULL);
-    break;
-  case TPM_DEVICE_1_2:
-    HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"TPM 1.2", NULL);
-    break;
-  case TPM_DEVICE_2_0_DTPM:
-    HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"TPM 2.0", NULL);
-    break;
-  default:
-    HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"Unknown", NULL);
-    break;
+    case TPM_DEVICE_NULL:
+      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"Not Found", NULL);
+      break;
+    case TPM_DEVICE_1_2:
+      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"TPM 1.2", NULL);
+      break;
+    case TPM_DEVICE_2_0_DTPM:
+      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"TPM 2.0", NULL);
+      break;
+    default:
+      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_STATE_CONTENT), L"Unknown", NULL);
+      break;
   }
 
-  ZeroMem (&Tcg2ConfigInfo, sizeof(Tcg2ConfigInfo));
+  ZeroMem (&Tcg2ConfigInfo, sizeof (Tcg2ConfigInfo));
   Status = Tpm2GetCapabilityPcrs (&Pcrs);
   if (EFI_ERROR (Status)) {
     HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TPM2_ACTIVE_HASH_ALGO_CONTENT), L"[Unknown]", NULL);
@@ -863,88 +888,101 @@ InstallTcg2ConfigForm (
     TempBuffer[0] = 0;
     for (Index = 0; Index < Pcrs.count; Index++) {
       if (!IsZeroBuffer (Pcrs.pcrSelections[Index].pcrSelect, Pcrs.pcrSelections[Index].sizeofSelect)) {
-        AppendBufferWithTpmAlgHash (TempBuffer, sizeof(TempBuffer), Pcrs.pcrSelections[Index].hash);
+        AppendBufferWithTpmAlgHash (TempBuffer, sizeof (TempBuffer), Pcrs.pcrSelections[Index].hash);
       }
     }
+
     HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TPM2_ACTIVE_HASH_ALGO_CONTENT), TempBuffer, NULL);
 
     TempBuffer[0] = 0;
     for (Index = 0; Index < Pcrs.count; Index++) {
-      AppendBufferWithTpmAlgHash (TempBuffer, sizeof(TempBuffer), Pcrs.pcrSelections[Index].hash);
+      AppendBufferWithTpmAlgHash (TempBuffer, sizeof (TempBuffer), Pcrs.pcrSelections[Index].hash);
       SetConfigInfo (&Tcg2ConfigInfo, Pcrs.pcrSelections[Index].hash);
     }
+
     HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TPM2_SUPPORTED_HASH_ALGO_CONTENT), TempBuffer, NULL);
   }
 
-  FillBufferWithBootHashAlg (TempBuffer, sizeof(TempBuffer), PcdGet32 (PcdTcg2HashAlgorithmBitmap));
+  Status = Tpm2GetCapabilityIsCommandImplemented (TPM_CC_ChangeEPS, &IsCmdImp);
+  if (EFI_ERROR (Status)) {
+    DEBUG ((DEBUG_ERROR, "Tpm2GetCapabilityIsCmdImpl fails %r\n", Status));
+  }
+
+  Tcg2ConfigInfo.ChangeEPSSupported = IsCmdImp;
+
+  FillBufferWithBootHashAlg (TempBuffer, sizeof (TempBuffer), PcdGet32 (PcdTcg2HashAlgorithmBitmap));
   HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_BIOS_HASH_ALGO_CONTENT), TempBuffer, NULL);
 
   //
   // Tcg2 Capability
   //
-  FillBufferWithTCG2EventLogFormat (TempBuffer, sizeof(TempBuffer), PrivateData->ProtocolCapability.SupportedEventLogs);
+  FillBufferWithTCG2EventLogFormat (TempBuffer, sizeof (TempBuffer), PrivateData->ProtocolCapability.SupportedEventLogs);
   HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_SUPPORTED_EVENT_LOG_FORMAT_CONTENT), TempBuffer, NULL);
 
-  FillBufferWithBootHashAlg (TempBuffer, sizeof(TempBuffer), PrivateData->ProtocolCapability.HashAlgorithmBitmap);
+  FillBufferWithBootHashAlg (TempBuffer, sizeof (TempBuffer), PrivateData->ProtocolCapability.HashAlgorithmBitmap);
   HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_HASH_ALGO_BITMAP_CONTENT), TempBuffer, NULL);
 
   UnicodeSPrint (TempBuffer, sizeof (TempBuffer), L"%d", PrivateData->ProtocolCapability.NumberOfPCRBanks);
   HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_NUMBER_OF_PCR_BANKS_CONTENT), TempBuffer, NULL);
 
-  FillBufferWithBootHashAlg (TempBuffer, sizeof(TempBuffer), PrivateData->ProtocolCapability.ActivePcrBanks);
+  FillBufferWithBootHashAlg (TempBuffer, sizeof (TempBuffer), PrivateData->ProtocolCapability.ActivePcrBanks);
   HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_ACTIVE_PCR_BANKS_CONTENT), TempBuffer, NULL);
 
   //
   // Update TPM device interface type
   //
   if (PrivateData->TpmDeviceDetected == TPM_DEVICE_2_0_DTPM) {
-    TpmDeviceInterfaceDetected = PcdGet8(PcdActiveTpmInterfaceType);
+    TpmDeviceInterfaceDetected = PcdGet8 (PcdActiveTpmInterfaceType);
     switch (TpmDeviceInterfaceDetected) {
-    case Tpm2PtpInterfaceTis:
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"TIS", NULL);
-      break;
-    case Tpm2PtpInterfaceFifo:
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"PTP FIFO", NULL);
-      break;
-    case Tpm2PtpInterfaceCrb:
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"PTP CRB", NULL);
-      break;
-     default:
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"Unknown", NULL);
-      break;
+      case Tpm2PtpInterfaceTis:
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"TIS", NULL);
+        break;
+      case Tpm2PtpInterfaceFifo:
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"PTP FIFO", NULL);
+        break;
+      case Tpm2PtpInterfaceCrb:
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"PTP CRB", NULL);
+        break;
+      default:
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_STATE_CONTENT), L"Unknown", NULL);
+        break;
     }
 
     Tcg2ConfigInfo.TpmDeviceInterfaceAttempt = TpmDeviceInterfaceDetected;
     switch (TpmDeviceInterfaceDetected) {
-    case Tpm2PtpInterfaceTis:
-      Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported = FALSE;
-      Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported  = FALSE;
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_CAPABILITY_CONTENT), L"TIS", NULL);
-      break;
-    case Tpm2PtpInterfaceFifo:
-    case Tpm2PtpInterfaceCrb:
-      Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported = IsPtpFifoSupported((VOID *) (UINTN) PcdGet64 (PcdTpmBaseAddress));
-      Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported  = IsPtpCrbSupported((VOID *) (UINTN) PcdGet64 (PcdTpmBaseAddress));
-      TempBuffer[0] = 0;
-      if (Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported) {
-        if (TempBuffer[0] != 0) {
-          StrCatS (TempBuffer, sizeof(TempBuffer) / sizeof (CHAR16), L", ");
+      case Tpm2PtpInterfaceTis:
+        Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported = FALSE;
+        Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported  = FALSE;
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_CAPABILITY_CONTENT), L"TIS", NULL);
+        break;
+      case Tpm2PtpInterfaceFifo:
+      case Tpm2PtpInterfaceCrb:
+        Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported = IsPtpFifoSupported ((VOID *)(UINTN)PcdGet64 (PcdTpmBaseAddress));
+        Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported  = IsPtpCrbSupported ((VOID *)(UINTN)PcdGet64 (PcdTpmBaseAddress));
+        TempBuffer[0]                                     = 0;
+        if (Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported) {
+          if (TempBuffer[0] != 0) {
+            StrCatS (TempBuffer, sizeof (TempBuffer) / sizeof (CHAR16), L", ");
+          }
+
+          StrCatS (TempBuffer, sizeof (TempBuffer) / sizeof (CHAR16), L"PTP FIFO");
         }
-        StrCatS (TempBuffer, sizeof(TempBuffer) / sizeof (CHAR16), L"PTP FIFO");
-      }
-      if (Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported) {
-        if (TempBuffer[0] != 0) {
-          StrCatS (TempBuffer, sizeof(TempBuffer) / sizeof (CHAR16), L", ");
+
+        if (Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported) {
+          if (TempBuffer[0] != 0) {
+            StrCatS (TempBuffer, sizeof (TempBuffer) / sizeof (CHAR16), L", ");
+          }
+
+          StrCatS (TempBuffer, sizeof (TempBuffer) / sizeof (CHAR16), L"PTP CRB");
         }
-        StrCatS (TempBuffer, sizeof(TempBuffer) / sizeof (CHAR16), L"PTP CRB");
-      }
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_CAPABILITY_CONTENT), TempBuffer, NULL);
-      break;
-    default:
-      Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported = FALSE;
-      Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported  = FALSE;
-      HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_CAPABILITY_CONTENT), L"Unknown", NULL);
-      break;
+
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_CAPABILITY_CONTENT), TempBuffer, NULL);
+        break;
+      default:
+        Tcg2ConfigInfo.TpmDeviceInterfacePtpFifoSupported = FALSE;
+        Tcg2ConfigInfo.TpmDeviceInterfacePtpCrbSupported  = FALSE;
+        HiiSetString (PrivateData->HiiHandle, STRING_TOKEN (STR_TCG2_DEVICE_INTERFACE_CAPABILITY_CONTENT), L"Unknown", NULL);
+        break;
     }
   }
 
@@ -955,11 +993,11 @@ InstallTcg2ConfigForm (
                   TCG2_STORAGE_INFO_NAME,
                   &gTcg2ConfigFormSetGuid,
                   EFI_VARIABLE_BOOTSERVICE_ACCESS,
-                  sizeof(Tcg2ConfigInfo),
+                  sizeof (Tcg2ConfigInfo),
                   &Tcg2ConfigInfo
                   );
   if (EFI_ERROR (Status)) {
-    DEBUG ((EFI_D_ERROR, "Tcg2ConfigDriver: Fail to set TCG2_STORAGE_INFO_NAME\n"));
+    DEBUG ((DEBUG_ERROR, "Tcg2ConfigDriver: Fail to set TCG2_STORAGE_INFO_NAME\n"));
   }
 
   return EFI_SUCCESS;
@@ -973,7 +1011,7 @@ InstallTcg2ConfigForm (
 **/
 VOID
 UninstallTcg2ConfigForm (
-  IN OUT TCG2_CONFIG_PRIVATE_DATA    *PrivateData
+  IN OUT TCG2_CONFIG_PRIVATE_DATA  *PrivateData
   )
 {
   //
