@@ -2,14 +2,8 @@
   MM Core Main Entry Point
 
   Copyright (c) 2009 - 2014, Intel Corporation. All rights reserved.<BR>
-  Copyright (c) 2016 - 2018, ARM Limited. All rights reserved.<BR>
-  This program and the accompanying materials are licensed and made available
-  under the terms and conditions of the BSD License which accompanies this
-  distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  Copyright (c) 2016 - 2021, Arm Limited. All rights reserved.<BR>
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -28,7 +22,7 @@ MmDispatcher (
 //
 // Globals used to initialize the protocol
 //
-EFI_HANDLE            mMmCpuHandle = NULL;
+EFI_HANDLE  mMmCpuHandle = NULL;
 
 //
 // Physical pointer to private structure shared between MM IPL and the MM Core
@@ -39,7 +33,6 @@ MM_CORE_PRIVATE_DATA  *gMmCorePrivate;
 // MM Core global variable for MM System Table.  Only accessed as a physical structure in MMRAM.
 //
 EFI_MM_SYSTEM_TABLE  gMmCoreMmst = {
-
   // The table header for the MMST.
   {
     MM_MMST_SIGNATURE,
@@ -55,12 +48,12 @@ EFI_MM_SYSTEM_TABLE  gMmCoreMmst = {
   // I/O Service
   {
     {
-      (EFI_MM_CPU_IO) MmEfiNotAvailableYetArg5,       // MmMemRead
-      (EFI_MM_CPU_IO) MmEfiNotAvailableYetArg5        // MmMemWrite
+      (EFI_MM_CPU_IO)MmEfiNotAvailableYetArg5,        // MmMemRead
+      (EFI_MM_CPU_IO)MmEfiNotAvailableYetArg5         // MmMemWrite
     },
     {
-      (EFI_MM_CPU_IO) MmEfiNotAvailableYetArg5,       // MmIoRead
-      (EFI_MM_CPU_IO) MmEfiNotAvailableYetArg5        // MmIoWrite
+      (EFI_MM_CPU_IO)MmEfiNotAvailableYetArg5,        // MmIoRead
+      (EFI_MM_CPU_IO)MmEfiNotAvailableYetArg5         // MmIoWrite
     }
   },
   // Runtime memory services
@@ -87,31 +80,20 @@ EFI_MM_SYSTEM_TABLE  gMmCoreMmst = {
   MmiHandlerUnRegister
 };
 
-//
-// Flag to determine if the platform has performed a legacy boot.
-// If this flag is TRUE, then the runtime code and runtime data associated with the
-// MM IPL are converted to free memory, so the MM Core must guarantee that is
-// does not touch of the code/data associated with the MM IPL if this flag is TRUE.
-//
-BOOLEAN  mInLegacyBoot = FALSE;
-
 //
 // Table of MMI Handlers that are registered by the MM Core when it is initialized
 //
 MM_CORE_MMI_HANDLERS  mMmCoreMmiHandlers[] = {
-  { MmFvDispatchHandler,     &gMmFvDispatchGuid,                 NULL, TRUE  },
-  { MmDriverDispatchHandler, &gEfiEventDxeDispatchGuid,          NULL, TRUE  },
-  { MmReadyToLockHandler,    &gEfiDxeMmReadyToLockProtocolGuid,  NULL, TRUE  },
-  { MmEndOfDxeHandler,       &gEfiEndOfDxeEventGroupGuid,        NULL, FALSE },
-  { MmLegacyBootHandler,     &gEfiEventLegacyBootGuid,           NULL, FALSE },
-  { MmExitBootServiceHandler,&gEfiEventExitBootServicesGuid,     NULL, FALSE },
-  { MmReadyToBootHandler,    &gEfiEventReadyToBootGuid,          NULL, FALSE },
-  { NULL,                    NULL,                               NULL, FALSE },
+  { MmReadyToLockHandler,     &gEfiDxeMmReadyToLockProtocolGuid, NULL, TRUE  },
+  { MmEndOfDxeHandler,        &gEfiEndOfDxeEventGroupGuid,       NULL, FALSE },
+  { MmExitBootServiceHandler, &gEfiEventExitBootServicesGuid,    NULL, FALSE },
+  { MmReadyToBootHandler,     &gEfiEventReadyToBootGuid,         NULL, FALSE },
+  { NULL,                     NULL,                              NULL, FALSE },
 };
 
-EFI_SYSTEM_TABLE                *mEfiSystemTable;
-UINTN                           mMmramRangeCount;
-EFI_MMRAM_DESCRIPTOR            *mMmramRanges;
+EFI_SYSTEM_TABLE      *mEfiSystemTable;
+UINTN                 mMmramRangeCount;
+EFI_MMRAM_DESCRIPTOR  *mMmramRanges;
 
 /**
   Place holder function until all the MM System Table Service are available.
@@ -130,11 +112,11 @@ EFI_MMRAM_DESCRIPTOR            *mMmramRanges;
 EFI_STATUS
 EFIAPI
 MmEfiNotAvailableYetArg5 (
-  UINTN Arg1,
-  UINTN Arg2,
-  UINTN Arg3,
-  UINTN Arg4,
-  UINTN Arg5
+  UINTN  Arg1,
+  UINTN  Arg2,
+  UINTN  Arg3,
+  UINTN  Arg4,
+  UINTN  Arg5
   )
 {
   //
@@ -144,47 +126,6 @@ MmEfiNotAvailableYetArg5 (
   return EFI_NOT_AVAILABLE_YET;
 }
 
-/**
-  Software MMI handler that is called when a Legacy Boot event is signaled.  The MM
-  Core uses this signal to know that a Legacy Boot has been performed and that
-  gMmCorePrivate that is shared between the UEFI and MM execution environments can
-  not be accessed from MM anymore since that structure is considered free memory by
-  a legacy OS.
-
-  @param  DispatchHandle  The unique handle assigned to this handler by MmiHandlerRegister().
-  @param  Context         Points to an optional handler context which was specified when the handler was registered.
-  @param  CommBuffer      A pointer to a collection of data in memory that will
-                          be conveyed from a non-MM environment into an MM environment.
-  @param  CommBufferSize  The size of the CommBuffer.
-
-  @return Status Code
-
-**/
-EFI_STATUS
-EFIAPI
-MmLegacyBootHandler (
-  IN     EFI_HANDLE  DispatchHandle,
-  IN     CONST VOID  *Context,        OPTIONAL
-  IN OUT VOID        *CommBuffer,     OPTIONAL
-  IN OUT UINTN       *CommBufferSize  OPTIONAL
-  )
-{
-  EFI_HANDLE  MmHandle;
-  EFI_STATUS  Status = EFI_SUCCESS;
-
-  if (!mInLegacyBoot) {
-    MmHandle = NULL;
-    Status = MmInstallProtocolInterface (
-               &MmHandle,
-               &gEfiEventLegacyBootGuid,
-               EFI_NATIVE_INTERFACE,
-               NULL
-               );
-  }
-  mInLegacyBoot = TRUE;
-  return Status;
-}
-
 /**
   Software MMI handler that is called when a ExitBoot Service event is signaled.
 
@@ -201,24 +142,26 @@ EFI_STATUS
 EFIAPI
 MmExitBootServiceHandler (
   IN     EFI_HANDLE  DispatchHandle,
-  IN     CONST VOID  *Context,        OPTIONAL
-  IN OUT VOID        *CommBuffer,     OPTIONAL
+  IN     CONST VOID  *Context         OPTIONAL,
+  IN OUT VOID        *CommBuffer      OPTIONAL,
   IN OUT UINTN       *CommBufferSize  OPTIONAL
   )
 {
-  EFI_HANDLE  MmHandle;
-  EFI_STATUS  Status = EFI_SUCCESS;
-  STATIC BOOLEAN mInExitBootServices = FALSE;
+  EFI_HANDLE      MmHandle;
+  EFI_STATUS      Status;
+  STATIC BOOLEAN  mInExitBootServices = FALSE;
 
+  Status = EFI_SUCCESS;
   if (!mInExitBootServices) {
     MmHandle = NULL;
-    Status = MmInstallProtocolInterface (
-               &MmHandle,
-               &gEfiEventExitBootServicesGuid,
-               EFI_NATIVE_INTERFACE,
-               NULL
-               );
+    Status   = MmInstallProtocolInterface (
+                 &MmHandle,
+                 &gEfiEventExitBootServicesGuid,
+                 EFI_NATIVE_INTERFACE,
+                 NULL
+                 );
   }
+
   mInExitBootServices = TRUE;
   return Status;
 }
@@ -239,24 +182,26 @@ EFI_STATUS
 EFIAPI
 MmReadyToBootHandler (
   IN     EFI_HANDLE  DispatchHandle,
-  IN     CONST VOID  *Context,        OPTIONAL
-  IN OUT VOID        *CommBuffer,     OPTIONAL
+  IN     CONST VOID  *Context         OPTIONAL,
+  IN OUT VOID        *CommBuffer      OPTIONAL,
   IN OUT UINTN       *CommBufferSize  OPTIONAL
   )
 {
-  EFI_HANDLE  MmHandle;
-  EFI_STATUS  Status = EFI_SUCCESS;
-  STATIC BOOLEAN mInReadyToBoot = FALSE;
+  EFI_HANDLE      MmHandle;
+  EFI_STATUS      Status;
+  STATIC BOOLEAN  mInReadyToBoot = FALSE;
 
+  Status = EFI_SUCCESS;
   if (!mInReadyToBoot) {
     MmHandle = NULL;
-    Status = MmInstallProtocolInterface (
-               &MmHandle,
-               &gEfiEventReadyToBootGuid,
-               EFI_NATIVE_INTERFACE,
-               NULL
-               );
+    Status   = MmInstallProtocolInterface (
+                 &MmHandle,
+                 &gEfiEventReadyToBootGuid,
+                 EFI_NATIVE_INTERFACE,
+                 NULL
+                 );
   }
+
   mInReadyToBoot = TRUE;
   return Status;
 }
@@ -281,8 +226,8 @@ EFI_STATUS
 EFIAPI
 MmReadyToLockHandler (
   IN     EFI_HANDLE  DispatchHandle,
-  IN     CONST VOID  *Context,        OPTIONAL
-  IN OUT VOID        *CommBuffer,     OPTIONAL
+  IN     CONST VOID  *Context         OPTIONAL,
+  IN OUT VOID        *CommBuffer      OPTIONAL,
   IN OUT UINTN       *CommBufferSize  OPTIONAL
   )
 {
@@ -305,36 +250,35 @@ MmReadyToLockHandler (
   // Install MM Ready to lock protocol
   //
   MmHandle = NULL;
-  Status = MmInstallProtocolInterface (
-             &MmHandle,
-             &gEfiMmReadyToLockProtocolGuid,
-             EFI_NATIVE_INTERFACE,
-             NULL
-             );
+  Status   = MmInstallProtocolInterface (
+               &MmHandle,
+               &gEfiMmReadyToLockProtocolGuid,
+               EFI_NATIVE_INTERFACE,
+               NULL
+               );
 
   //
   // Make sure MM CPU I/O 2 Protocol has been installed into the handle database
   //
-  //Status = MmLocateProtocol (&EFI_MM_CPU_IO_PROTOCOL_GUID, NULL, &Interface);
+  // Status = MmLocateProtocol (&EFI_MM_CPU_IO_PROTOCOL_GUID, NULL, &Interface);
 
   //
   // Print a message on a debug build if the MM CPU I/O 2 Protocol is not installed
   //
-  //if (EFI_ERROR (Status)) {
-      //DEBUG ((DEBUG_ERROR, "\nSMM: SmmCpuIo Arch Protocol not present!!\n"));
-  //}
-
+  // if (EFI_ERROR (Status)) {
+  // DEBUG ((DEBUG_ERROR, "\nSMM: SmmCpuIo Arch Protocol not present!!\n"));
+  // }
 
   //
   // Assert if the CPU I/O 2 Protocol is not installed
   //
-  //ASSERT_EFI_ERROR (Status);
+  // ASSERT_EFI_ERROR (Status);
 
   //
   // Display any drivers that were not dispatched because dependency expression
   // evaluated to false if this is a debug build
   //
-  //MmDisplayDiscoveredNotDispatched ();
+  // MmDisplayDiscoveredNotDispatched ();
 
   return Status;
 }
@@ -357,8 +301,8 @@ EFI_STATUS
 EFIAPI
 MmEndOfDxeHandler (
   IN     EFI_HANDLE  DispatchHandle,
-  IN     CONST VOID  *Context,        OPTIONAL
-  IN OUT VOID        *CommBuffer,     OPTIONAL
+  IN     CONST VOID  *Context         OPTIONAL,
+  IN OUT VOID        *CommBuffer      OPTIONAL,
   IN OUT UINTN       *CommBufferSize  OPTIONAL
   )
 {
@@ -370,17 +314,15 @@ MmEndOfDxeHandler (
   // Install MM EndOfDxe protocol
   //
   MmHandle = NULL;
-  Status = MmInstallProtocolInterface (
-             &MmHandle,
-             &gEfiMmEndOfDxeProtocolGuid,
-             EFI_NATIVE_INTERFACE,
-             NULL
-             );
+  Status   = MmInstallProtocolInterface (
+               &MmHandle,
+               &gEfiMmEndOfDxeProtocolGuid,
+               EFI_NATIVE_INTERFACE,
+               NULL
+               );
   return Status;
 }
 
-
-
 /**
   The main entry point to MM Foundation.
 
@@ -394,11 +336,10 @@ VOID
 EFIAPI
 MmEntryPoint (
   IN CONST EFI_MM_ENTRY_CONTEXT  *MmEntryContext
-)
+  )
 {
-  EFI_STATUS                  Status;
+  EFI_STATUS                 Status;
   EFI_MM_COMMUNICATE_HEADER  *CommunicateHeader;
-  BOOLEAN                     InLegacyBoot;
 
   DEBUG ((DEBUG_INFO, "MmEntryPoint ...\n"));
 
@@ -410,49 +351,47 @@ MmEntryPoint (
   //
   // Call platform hook before Mm Dispatch
   //
-  //PlatformHookBeforeMmDispatch ();
+  // PlatformHookBeforeMmDispatch ();
 
   //
-  // If a legacy boot has occured, then make sure gMmCorePrivate is not accessed
+  // If a legacy boot has occurred, then make sure gMmCorePrivate is not accessed
   //
-  InLegacyBoot = mInLegacyBoot;
-  if (!InLegacyBoot) {
-    //
-    // TBD: Mark the InMm flag as TRUE
-    //
-    gMmCorePrivate->InMm = TRUE;
 
+  //
+  // TBD: Mark the InMm flag as TRUE
+  //
+  gMmCorePrivate->InMm = TRUE;
+
+  //
+  // Check to see if this is a Synchronous MMI sent through the MM Communication
+  // Protocol or an Asynchronous MMI
+  //
+  if (gMmCorePrivate->CommunicationBuffer != 0) {
     //
-    // Check to see if this is a Synchronous MMI sent through the MM Communication
-    // Protocol or an Asynchronous MMI
+    // Synchronous MMI for MM Core or request from Communicate protocol
     //
-    if (gMmCorePrivate->CommunicationBuffer != 0) {
+    if (!MmIsBufferOutsideMmValid ((UINTN)gMmCorePrivate->CommunicationBuffer, gMmCorePrivate->BufferSize)) {
       //
-      // Synchronous MMI for MM Core or request from Communicate protocol
+      // If CommunicationBuffer is not in valid address scope, return EFI_INVALID_PARAMETER
       //
-      if (!MmIsBufferOutsideMmValid ((UINTN)gMmCorePrivate->CommunicationBuffer, gMmCorePrivate->BufferSize)) {
-        //
-        // If CommunicationBuffer is not in valid address scope, return EFI_INVALID_PARAMETER
-        //
-        gMmCorePrivate->CommunicationBuffer = 0;
-        gMmCorePrivate->ReturnStatus = EFI_INVALID_PARAMETER;
-      } else {
-        CommunicateHeader = (EFI_MM_COMMUNICATE_HEADER *)(UINTN)gMmCorePrivate->CommunicationBuffer;
-        gMmCorePrivate->BufferSize -= OFFSET_OF (EFI_MM_COMMUNICATE_HEADER, Data);
-        Status = MmiManage (
-                   &CommunicateHeader->HeaderGuid,
-                   NULL,
-                   CommunicateHeader->Data,
-                   (UINTN *)&gMmCorePrivate->BufferSize
-                   );
-        //
-        // Update CommunicationBuffer, BufferSize and ReturnStatus
-        // Communicate service finished, reset the pointer to CommBuffer to NULL
-        //
-        gMmCorePrivate->BufferSize += OFFSET_OF (EFI_MM_COMMUNICATE_HEADER, Data);
-        gMmCorePrivate->CommunicationBuffer = 0;
-        gMmCorePrivate->ReturnStatus = (Status == EFI_SUCCESS) ? EFI_SUCCESS : EFI_NOT_FOUND;
-      }
+      gMmCorePrivate->CommunicationBuffer = 0;
+      gMmCorePrivate->ReturnStatus        = EFI_INVALID_PARAMETER;
+    } else {
+      CommunicateHeader           = (EFI_MM_COMMUNICATE_HEADER *)(UINTN)gMmCorePrivate->CommunicationBuffer;
+      gMmCorePrivate->BufferSize -= OFFSET_OF (EFI_MM_COMMUNICATE_HEADER, Data);
+      Status                      = MmiManage (
+                                      &CommunicateHeader->HeaderGuid,
+                                      NULL,
+                                      CommunicateHeader->Data,
+                                      (UINTN *)&gMmCorePrivate->BufferSize
+                                      );
+      //
+      // Update CommunicationBuffer, BufferSize and ReturnStatus
+      // Communicate service finished, reset the pointer to CommBuffer to NULL
+      //
+      gMmCorePrivate->BufferSize         += OFFSET_OF (EFI_MM_COMMUNICATE_HEADER, Data);
+      gMmCorePrivate->CommunicationBuffer = 0;
+      gMmCorePrivate->ReturnStatus        = (Status == EFI_SUCCESS) ? EFI_SUCCESS : EFI_NOT_FOUND;
     }
   }
 
@@ -466,27 +405,31 @@ MmEntryPoint (
   //
 
   //
-  // If a legacy boot has occured, then make sure gMmCorePrivate is not accessed
+  // Clear the InMm flag as we are going to leave MM
   //
-  if (!InLegacyBoot) {
-    //
-    // Clear the InMm flag as we are going to leave MM
-    //
-    gMmCorePrivate->InMm = FALSE;
-  }
+  gMmCorePrivate->InMm = FALSE;
 
   DEBUG ((DEBUG_INFO, "MmEntryPoint Done\n"));
 }
 
+/** Register the MM Entry Point provided by the MM Core with the
+    MM Configuration protocol.
+
+  @param [in]  Protocol   Pointer to the protocol.
+  @param [in]  Interface  Pointer to the MM Configuration protocol.
+  @param [in]  Handle     Handle.
+
+  @retval EFI_SUCCESS             Success.
+**/
 EFI_STATUS
 EFIAPI
 MmConfigurationMmNotify (
-  IN CONST EFI_GUID *Protocol,
-  IN VOID           *Interface,
+  IN CONST EFI_GUID  *Protocol,
+  IN VOID            *Interface,
   IN EFI_HANDLE      Handle
   )
 {
-  EFI_STATUS                      Status;
+  EFI_STATUS                     Status;
   EFI_MM_CONFIGURATION_PROTOCOL  *MmConfiguration;
 
   DEBUG ((DEBUG_INFO, "MmConfigurationMmNotify(%g) - %x\n", Protocol, Interface));
@@ -512,19 +455,26 @@ MmConfigurationMmNotify (
   return EFI_SUCCESS;
 }
 
+/** Returns the HOB list size.
+
+  @param [in]  HobStart   Pointer to the start of the HOB list.
+
+  @retval Size of the HOB list.
+**/
 UINTN
 GetHobListSize (
-  IN VOID *HobStart
+  IN VOID  *HobStart
   )
 {
   EFI_PEI_HOB_POINTERS  Hob;
 
   ASSERT (HobStart != NULL);
 
-  Hob.Raw = (UINT8 *) HobStart;
+  Hob.Raw = (UINT8 *)HobStart;
   while (!END_OF_HOB_LIST (Hob)) {
     Hob.Raw = GET_NEXT_HOB (Hob);
   }
+
   //
   // Need plus END_OF_HOB_LIST
   //
@@ -539,12 +489,10 @@ GetHobListSize (
 
   Note: This function is called for both DXE invocation and MMRAM invocation.
 
-  @param  ImageHandle    The firmware allocated handle for the EFI image.
-  @param  SystemTable    A pointer to the EFI System Table.
-
-  @retval EFI_SUCCESS    The entry point is executed successfully.
-  @retval Other          Some error occurred when executing this entry point.
+  @param  HobStart       Pointer to the start of the HOB list.
 
+  @retval EFI_SUCCESS             Success.
+  @retval EFI_UNSUPPORTED         Unsupported operation.
 **/
 EFI_STATUS
 EFIAPI
@@ -562,7 +510,7 @@ StandaloneMmMain (
   EFI_HOB_GUID_TYPE               *MmramRangesHob;
   EFI_MMRAM_HOB_DESCRIPTOR_BLOCK  *MmramRangesHobData;
   EFI_MMRAM_DESCRIPTOR            *MmramRanges;
-  UINT32                          MmramRangeCount;
+  UINTN                           MmramRangeCount;
   EFI_HOB_FIRMWARE_VOLUME         *BfvHob;
 
   ProcessLibraryConstructorList (HobStart, &gMmCoreMmst);
@@ -580,24 +528,25 @@ StandaloneMmMain (
     // Allocate and zero memory for a MM_CORE_PRIVATE_DATA table and then
     // initialise it
     //
-    gMmCorePrivate = (MM_CORE_PRIVATE_DATA *) AllocateRuntimePages(EFI_SIZE_TO_PAGES(sizeof (MM_CORE_PRIVATE_DATA)));
+    gMmCorePrivate = (MM_CORE_PRIVATE_DATA *)AllocateRuntimePages (EFI_SIZE_TO_PAGES (sizeof (MM_CORE_PRIVATE_DATA)));
     SetMem ((VOID *)(UINTN)gMmCorePrivate, sizeof (MM_CORE_PRIVATE_DATA), 0);
-    gMmCorePrivate->Signature = MM_CORE_PRIVATE_DATA_SIGNATURE;
+    gMmCorePrivate->Signature              = MM_CORE_PRIVATE_DATA_SIGNATURE;
     gMmCorePrivate->MmEntryPointRegistered = FALSE;
-    gMmCorePrivate->InMm = FALSE;
-    gMmCorePrivate->ReturnStatus = EFI_SUCCESS;
+    gMmCorePrivate->InMm                   = FALSE;
+    gMmCorePrivate->ReturnStatus           = EFI_SUCCESS;
 
     //
     // Extract the MMRAM ranges from the MMRAM descriptor HOB
     //
     MmramRangesHob = GetNextGuidHob (&gEfiMmPeiMmramMemoryReserveGuid, HobStart);
-    if (MmramRangesHob == NULL)
+    if (MmramRangesHob == NULL) {
       return EFI_UNSUPPORTED;
+    }
 
     MmramRangesHobData = GET_GUID_HOB_DATA (MmramRangesHob);
     ASSERT (MmramRangesHobData != NULL);
-    MmramRanges = MmramRangesHobData->Descriptor;
-    MmramRangeCount = MmramRangesHobData->NumberOfMmReservedRegions;
+    MmramRanges     = MmramRangesHobData->Descriptor;
+    MmramRangeCount = (UINTN)MmramRangesHobData->NumberOfMmReservedRegions;
     ASSERT (MmramRanges);
     ASSERT (MmramRangeCount);
 
@@ -605,8 +554,8 @@ StandaloneMmMain (
     // Copy the MMRAM ranges into MM_CORE_PRIVATE_DATA table just in case any
     // code relies on them being present there
     //
-    gMmCorePrivate->MmramRangeCount = MmramRangeCount;
-    gMmCorePrivate->MmramRanges =
+    gMmCorePrivate->MmramRangeCount = (UINT64)MmramRangeCount;
+    gMmCorePrivate->MmramRanges     =
       (EFI_PHYSICAL_ADDRESS)(UINTN)AllocatePool (MmramRangeCount * sizeof (EFI_MMRAM_DESCRIPTOR));
     ASSERT (gMmCorePrivate->MmramRanges != 0);
     CopyMem (
@@ -616,9 +565,9 @@ StandaloneMmMain (
       );
   } else {
     DataInHob       = GET_GUID_HOB_DATA (GuidHob);
-    gMmCorePrivate = (MM_CORE_PRIVATE_DATA *)(UINTN)DataInHob->Address;
+    gMmCorePrivate  = (MM_CORE_PRIVATE_DATA *)(UINTN)DataInHob->Address;
     MmramRanges     = (EFI_MMRAM_DESCRIPTOR *)(UINTN)gMmCorePrivate->MmramRanges;
-    MmramRangeCount = gMmCorePrivate->MmramRangeCount;
+    MmramRangeCount = (UINTN)gMmCorePrivate->MmramRangeCount;
   }
 
   //
@@ -626,9 +575,13 @@ StandaloneMmMain (
   //
   DEBUG ((DEBUG_INFO, "MmramRangeCount - 0x%x\n", MmramRangeCount));
   for (Index = 0; Index < MmramRangeCount; Index++) {
-          DEBUG ((DEBUG_INFO, "MmramRanges[%d]: 0x%016lx - 0x%lx\n", Index,
-                  MmramRanges[Index].CpuStart,
-                  MmramRanges[Index].PhysicalSize));
+    DEBUG ((
+      DEBUG_INFO,
+      "MmramRanges[%d]: 0x%016lx - 0x%lx\n",
+      Index,
+      MmramRanges[Index].CpuStart,
+      MmramRanges[Index].PhysicalSize
+      ));
   }
 
   //
@@ -651,14 +604,14 @@ StandaloneMmMain (
     gMmCorePrivate->StandaloneBfvAddress = BfvHob->BaseAddress;
   }
 
-  gMmCorePrivate->Mmst          = (EFI_PHYSICAL_ADDRESS)(UINTN)&gMmCoreMmst;
+  gMmCorePrivate->Mmst         = (EFI_PHYSICAL_ADDRESS)(UINTN)&gMmCoreMmst;
   gMmCorePrivate->MmEntryPoint = (EFI_PHYSICAL_ADDRESS)(UINTN)MmEntryPoint;
 
   //
   // No need to initialize memory service.
-  // It is done in constructor of StandaloneMmCoreMemoryAllocationLib(),
-  // so that the library linked with StandaloneMmCore can use AllocatePool() in constuctor.
-  //
+  // It is done in the constructor of StandaloneMmCoreMemoryAllocationLib(),
+  // so that the library linked with StandaloneMmCore can use AllocatePool() in
+  // the constructor.
 
   DEBUG ((DEBUG_INFO, "MmInstallConfigurationTable For HobList\n"));
   //
