@@ -3,23 +3,17 @@
 
   This local APIC library instance supports xAPIC mode only.
 
-  Copyright (c) 2010 - 2018, Intel Corporation. All rights reserved.<BR>
-  Copyright (c) 2017, AMD Inc. All rights reserved.<BR>
+  Copyright (c) 2010 - 2019, Intel Corporation. All rights reserved.<BR>
+  Copyright (c) 2017 - 2020, AMD Inc. All rights reserved.<BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
-#include <Register/Cpuid.h>
+#include <Register/Intel/Cpuid.h>
 #include <Register/Amd/Cpuid.h>
-#include <Register/Msr.h>
-#include <Register/LocalApic.h>
+#include <Register/Intel/Msr.h>
+#include <Register/Intel/LocalApic.h>
 
 #include <Library/BaseLib.h>
 #include <Library/DebugLib.h>
@@ -27,33 +21,13 @@
 #include <Library/IoLib.h>
 #include <Library/TimerLib.h>
 #include <Library/PcdLib.h>
+#include <Library/CpuLib.h>
+#include <Library/UefiCpuLib.h>
 
 //
 // Library internal functions
 //
 
-/**
-  Determine if the standard CPU signature is "AuthenticAMD".
-
-  @retval TRUE  The CPU signature matches.
-  @retval FALSE The CPU signature does not match.
-
-**/
-BOOLEAN
-StandardSignatureIsAuthenticAMD (
-  VOID
-  )
-{
-  UINT32  RegEbx;
-  UINT32  RegEcx;
-  UINT32  RegEdx;
-
-  AsmCpuid (CPUID_SIGNATURE, NULL, &RegEbx, &RegEcx, &RegEdx);
-  return (RegEbx == CPUID_SIGNATURE_AUTHENTIC_AMD_EBX &&
-          RegEcx == CPUID_SIGNATURE_AUTHENTIC_AMD_ECX &&
-          RegEdx == CPUID_SIGNATURE_AUTHENTIC_AMD_EDX);
-}
-
 /**
   Determine if the CPU supports the Local APIC Base Address MSR.
 
@@ -71,13 +45,14 @@ LocalApicBaseAddressMsrSupported (
 
   AsmCpuid (1, &RegEax, NULL, NULL, NULL);
   FamilyId = BitFieldRead32 (RegEax, 8, 11);
-  if (FamilyId == 0x04 || FamilyId == 0x05) {
+  if ((FamilyId == 0x04) || (FamilyId == 0x05)) {
     //
     // CPUs with a FamilyId of 0x04 or 0x05 do not support the
     // Local APIC Base Address MSR
     //
     return FALSE;
   }
+
   return TRUE;
 }
 
@@ -105,8 +80,8 @@ GetLocalApicBaseAddress (
 
   ApicBaseMsr.Uint64 = AsmReadMsr64 (MSR_IA32_APIC_BASE);
 
-  return (UINTN)(LShiftU64 ((UINT64) ApicBaseMsr.Bits.ApicBaseHi, 32)) +
-           (((UINTN)ApicBaseMsr.Bits.ApicBase) << 12);
+  return (UINTN)(LShiftU64 ((UINT64)ApicBaseMsr.Bits.ApicBaseHi, 32)) +
+         (((UINTN)ApicBaseMsr.Bits.ApicBase) << 12);
 }
 
 /**
@@ -120,7 +95,7 @@ GetLocalApicBaseAddress (
 VOID
 EFIAPI
 SetLocalApicBaseAddress (
-  IN UINTN                BaseAddress
+  IN UINTN  BaseAddress
   )
 {
   MSR_IA32_APIC_BASE_REGISTER  ApicBaseMsr;
@@ -136,8 +111,8 @@ SetLocalApicBaseAddress (
 
   ApicBaseMsr.Uint64 = AsmReadMsr64 (MSR_IA32_APIC_BASE);
 
-  ApicBaseMsr.Bits.ApicBase   = (UINT32) (BaseAddress >> 12);
-  ApicBaseMsr.Bits.ApicBaseHi = (UINT32) (RShiftU64((UINT64) BaseAddress, 32));
+  ApicBaseMsr.Bits.ApicBase   = (UINT32)(BaseAddress >> 12);
+  ApicBaseMsr.Bits.ApicBaseHi = (UINT32)(RShiftU64 ((UINT64)BaseAddress, 32));
 
   AsmWriteMsr64 (MSR_IA32_APIC_BASE, ApicBaseMsr.Uint64);
 }
@@ -164,7 +139,7 @@ ReadLocalApicReg (
   ASSERT ((MmioOffset & 0xf) == 0);
   ASSERT (GetApicMode () == LOCAL_APIC_MODE_XAPIC);
 
-  return MmioRead32 (GetLocalApicBaseAddress() + MmioOffset);
+  return MmioRead32 (GetLocalApicBaseAddress () + MmioOffset);
 }
 
 /**
@@ -184,14 +159,14 @@ ReadLocalApicReg (
 VOID
 EFIAPI
 WriteLocalApicReg (
-  IN UINTN  MmioOffset,
-  IN UINT32 Value
+  IN UINTN   MmioOffset,
+  IN UINT32  Value
   )
 {
   ASSERT ((MmioOffset & 0xf) == 0);
   ASSERT (GetApicMode () == LOCAL_APIC_MODE_XAPIC);
 
-  MmioWrite32 (GetLocalApicBaseAddress() + MmioOffset, Value);
+  MmioWrite32 (GetLocalApicBaseAddress () + MmioOffset, Value);
 }
 
 /**
@@ -204,13 +179,13 @@ WriteLocalApicReg (
 **/
 VOID
 SendIpi (
-  IN UINT32          IcrLow,
-  IN UINT32          ApicId
+  IN UINT32  IcrLow,
+  IN UINT32  ApicId
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLowReg;
-  UINT32             IcrHigh;
-  BOOLEAN            InterruptState;
+  LOCAL_APIC_ICR_LOW  IcrLowReg;
+  UINT32              IcrHigh;
+  BOOLEAN             InterruptState;
 
   ASSERT (GetApicMode () == LOCAL_APIC_MODE_XAPIC);
   ASSERT (ApicId <= 0xff);
@@ -249,7 +224,6 @@ SendIpi (
   WriteLocalApicReg (XAPIC_ICR_HIGH_OFFSET, IcrHigh);
 
   SetInterruptState (InterruptState);
-
 }
 
 //
@@ -270,23 +244,23 @@ GetApicMode (
   VOID
   )
 {
-  DEBUG_CODE (
-    {
-      MSR_IA32_APIC_BASE_REGISTER  ApicBaseMsr;
+  DEBUG_CODE_BEGIN ();
+  {
+    MSR_IA32_APIC_BASE_REGISTER  ApicBaseMsr;
 
+    //
+    // Check to see if the CPU supports the APIC Base Address MSR
+    //
+    if (LocalApicBaseAddressMsrSupported ()) {
+      ApicBaseMsr.Uint64 = AsmReadMsr64 (MSR_IA32_APIC_BASE);
       //
-      // Check to see if the CPU supports the APIC Base Address MSR
+      // Local APIC should have been enabled
       //
-      if (LocalApicBaseAddressMsrSupported ()) {
-        ApicBaseMsr.Uint64 = AsmReadMsr64 (MSR_IA32_APIC_BASE);
-        //
-        // Local APIC should have been enabled
-        //
-        ASSERT (ApicBaseMsr.Bits.EN != 0);
-        ASSERT (ApicBaseMsr.Bits.EXTD == 0);
-      }
+      ASSERT (ApicBaseMsr.Bits.EN != 0);
+      ASSERT (ApicBaseMsr.Bits.EXTD == 0);
     }
-  );
+  }
+  DEBUG_CODE_END ();
   return LOCAL_APIC_MODE_XAPIC;
 }
 
@@ -326,9 +300,9 @@ GetInitialApicId (
   VOID
   )
 {
-  UINT32 ApicId;
-  UINT32 MaxCpuIdIndex;
-  UINT32 RegEbx;
+  UINT32  ApicId;
+  UINT32  MaxCpuIdIndex;
+  UINT32  RegEbx;
 
   ASSERT (GetApicMode () == LOCAL_APIC_MODE_XAPIC);
 
@@ -365,7 +339,7 @@ GetApicId (
   VOID
   )
 {
-  UINT32 ApicId;
+  UINT32  ApicId;
 
   ASSERT (GetApicMode () == LOCAL_APIC_MODE_XAPIC);
 
@@ -374,9 +348,10 @@ GetApicId (
     // If the initial local APIC ID is less 0x100, read APIC ID from
     // XAPIC_ID_OFFSET, otherwise return the initial local APIC ID.
     //
-    ApicId = ReadLocalApicReg (XAPIC_ID_OFFSET);
+    ApicId   = ReadLocalApicReg (XAPIC_ID_OFFSET);
     ApicId >>= 24;
   }
+
   return ApicId;
 }
 
@@ -405,16 +380,16 @@ GetApicVersion (
 VOID
 EFIAPI
 SendFixedIpi (
-  IN UINT32          ApicId,
-  IN UINT8           Vector
+  IN UINT32  ApicId,
+  IN UINT8   Vector
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
-  IcrLow.Uint32 = 0;
+  IcrLow.Uint32            = 0;
   IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_FIXED;
-  IcrLow.Bits.Level = 1;
-  IcrLow.Bits.Vector = Vector;
+  IcrLow.Bits.Level        = 1;
+  IcrLow.Bits.Vector       = Vector;
   SendIpi (IcrLow.Uint32, ApicId);
 }
 
@@ -428,16 +403,16 @@ SendFixedIpi (
 VOID
 EFIAPI
 SendFixedIpiAllExcludingSelf (
-  IN UINT8           Vector
+  IN UINT8  Vector
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
-  IcrLow.Uint32 = 0;
-  IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_FIXED;
-  IcrLow.Bits.Level = 1;
+  IcrLow.Uint32                    = 0;
+  IcrLow.Bits.DeliveryMode         = LOCAL_APIC_DELIVERY_MODE_FIXED;
+  IcrLow.Bits.Level                = 1;
   IcrLow.Bits.DestinationShorthand = LOCAL_APIC_DESTINATION_SHORTHAND_ALL_EXCLUDING_SELF;
-  IcrLow.Bits.Vector = Vector;
+  IcrLow.Bits.Vector               = Vector;
   SendIpi (IcrLow.Uint32, 0);
 }
 
@@ -451,14 +426,14 @@ SendFixedIpiAllExcludingSelf (
 VOID
 EFIAPI
 SendSmiIpi (
-  IN UINT32          ApicId
+  IN UINT32  ApicId
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
-  IcrLow.Uint32 = 0;
+  IcrLow.Uint32            = 0;
   IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_SMI;
-  IcrLow.Bits.Level = 1;
+  IcrLow.Bits.Level        = 1;
   SendIpi (IcrLow.Uint32, ApicId);
 }
 
@@ -473,11 +448,11 @@ SendSmiIpiAllExcludingSelf (
   VOID
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
-  IcrLow.Uint32 = 0;
-  IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_SMI;
-  IcrLow.Bits.Level = 1;
+  IcrLow.Uint32                    = 0;
+  IcrLow.Bits.DeliveryMode         = LOCAL_APIC_DELIVERY_MODE_SMI;
+  IcrLow.Bits.Level                = 1;
   IcrLow.Bits.DestinationShorthand = LOCAL_APIC_DESTINATION_SHORTHAND_ALL_EXCLUDING_SELF;
   SendIpi (IcrLow.Uint32, 0);
 }
@@ -492,14 +467,14 @@ SendSmiIpiAllExcludingSelf (
 VOID
 EFIAPI
 SendInitIpi (
-  IN UINT32          ApicId
+  IN UINT32  ApicId
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
-  IcrLow.Uint32 = 0;
+  IcrLow.Uint32            = 0;
   IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_INIT;
-  IcrLow.Bits.Level = 1;
+  IcrLow.Bits.Level        = 1;
   SendIpi (IcrLow.Uint32, ApicId);
 }
 
@@ -514,11 +489,11 @@ SendInitIpiAllExcludingSelf (
   VOID
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
-  IcrLow.Uint32 = 0;
-  IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_INIT;
-  IcrLow.Bits.Level = 1;
+  IcrLow.Uint32                    = 0;
+  IcrLow.Bits.DeliveryMode         = LOCAL_APIC_DELIVERY_MODE_INIT;
+  IcrLow.Bits.Level                = 1;
   IcrLow.Bits.DestinationShorthand = LOCAL_APIC_DESTINATION_SHORTHAND_ALL_EXCLUDING_SELF;
   SendIpi (IcrLow.Uint32, 0);
 }
@@ -538,21 +513,21 @@ SendInitIpiAllExcludingSelf (
 VOID
 EFIAPI
 SendInitSipiSipi (
-  IN UINT32          ApicId,
-  IN UINT32          StartupRoutine
+  IN UINT32  ApicId,
+  IN UINT32  StartupRoutine
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
   ASSERT (StartupRoutine < 0x100000);
   ASSERT ((StartupRoutine & 0xfff) == 0);
 
   SendInitIpi (ApicId);
-  MicroSecondDelay (PcdGet32(PcdCpuInitIpiDelayInMicroSeconds));
-  IcrLow.Uint32 = 0;
-  IcrLow.Bits.Vector = (StartupRoutine >> 12);
+  MicroSecondDelay (PcdGet32 (PcdCpuInitIpiDelayInMicroSeconds));
+  IcrLow.Uint32            = 0;
+  IcrLow.Bits.Vector       = (StartupRoutine >> 12);
   IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_STARTUP;
-  IcrLow.Bits.Level = 1;
+  IcrLow.Bits.Level        = 1;
   SendIpi (IcrLow.Uint32, ApicId);
   if (!StandardSignatureIsAuthenticAMD ()) {
     MicroSecondDelay (200);
@@ -574,20 +549,20 @@ SendInitSipiSipi (
 VOID
 EFIAPI
 SendInitSipiSipiAllExcludingSelf (
-  IN UINT32          StartupRoutine
+  IN UINT32  StartupRoutine
   )
 {
-  LOCAL_APIC_ICR_LOW IcrLow;
+  LOCAL_APIC_ICR_LOW  IcrLow;
 
   ASSERT (StartupRoutine < 0x100000);
   ASSERT ((StartupRoutine & 0xfff) == 0);
 
   SendInitIpiAllExcludingSelf ();
-  MicroSecondDelay (PcdGet32(PcdCpuInitIpiDelayInMicroSeconds));
-  IcrLow.Uint32 = 0;
-  IcrLow.Bits.Vector = (StartupRoutine >> 12);
-  IcrLow.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_STARTUP;
-  IcrLow.Bits.Level = 1;
+  MicroSecondDelay (PcdGet32 (PcdCpuInitIpiDelayInMicroSeconds));
+  IcrLow.Uint32                    = 0;
+  IcrLow.Bits.Vector               = (StartupRoutine >> 12);
+  IcrLow.Bits.DeliveryMode         = LOCAL_APIC_DELIVERY_MODE_STARTUP;
+  IcrLow.Bits.Level                = 1;
   IcrLow.Bits.DestinationShorthand = LOCAL_APIC_DESTINATION_SHORTHAND_ALL_EXCLUDING_SELF;
   SendIpi (IcrLow.Uint32, 0);
   if (!StandardSignatureIsAuthenticAMD ()) {
@@ -643,13 +618,13 @@ ProgramVirtualWireMode (
   VOID
   )
 {
-  LOCAL_APIC_SVR      Svr;
-  LOCAL_APIC_LVT_LINT Lint;
+  LOCAL_APIC_SVR       Svr;
+  LOCAL_APIC_LVT_LINT  Lint;
 
   //
   // Enable the APIC via SVR and set the spurious interrupt to use Int 00F.
   //
-  Svr.Uint32 = ReadLocalApicReg (XAPIC_SPURIOUS_VECTOR_OFFSET);
+  Svr.Uint32              = ReadLocalApicReg (XAPIC_SPURIOUS_VECTOR_OFFSET);
   Svr.Bits.SpuriousVector = 0xf;
   Svr.Bits.SoftwareEnable = 1;
   WriteLocalApicReg (XAPIC_SPURIOUS_VECTOR_OFFSET, Svr.Uint32);
@@ -657,21 +632,21 @@ ProgramVirtualWireMode (
   //
   // Program the LINT0 vector entry as ExtInt. Not masked, edge, active high.
   //
-  Lint.Uint32 = ReadLocalApicReg (XAPIC_LVT_LINT0_OFFSET);
-  Lint.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_EXTINT;
+  Lint.Uint32                = ReadLocalApicReg (XAPIC_LVT_LINT0_OFFSET);
+  Lint.Bits.DeliveryMode     = LOCAL_APIC_DELIVERY_MODE_EXTINT;
   Lint.Bits.InputPinPolarity = 0;
-  Lint.Bits.TriggerMode = 0;
-  Lint.Bits.Mask = 0;
+  Lint.Bits.TriggerMode      = 0;
+  Lint.Bits.Mask             = 0;
   WriteLocalApicReg (XAPIC_LVT_LINT0_OFFSET, Lint.Uint32);
 
   //
   // Program the LINT0 vector entry as NMI. Not masked, edge, active high.
   //
-  Lint.Uint32 = ReadLocalApicReg (XAPIC_LVT_LINT1_OFFSET);
-  Lint.Bits.DeliveryMode = LOCAL_APIC_DELIVERY_MODE_NMI;
+  Lint.Uint32                = ReadLocalApicReg (XAPIC_LVT_LINT1_OFFSET);
+  Lint.Bits.DeliveryMode     = LOCAL_APIC_DELIVERY_MODE_NMI;
   Lint.Bits.InputPinPolarity = 0;
-  Lint.Bits.TriggerMode = 0;
-  Lint.Bits.Mask = 0;
+  Lint.Bits.TriggerMode      = 0;
+  Lint.Bits.Mask             = 0;
   WriteLocalApicReg (XAPIC_LVT_LINT1_OFFSET, Lint.Uint32);
 }
 
@@ -686,13 +661,13 @@ DisableLvtInterrupts (
   VOID
   )
 {
-  LOCAL_APIC_LVT_LINT LvtLint;
+  LOCAL_APIC_LVT_LINT  LvtLint;
 
-  LvtLint.Uint32 = ReadLocalApicReg (XAPIC_LVT_LINT0_OFFSET);
+  LvtLint.Uint32    = ReadLocalApicReg (XAPIC_LVT_LINT0_OFFSET);
   LvtLint.Bits.Mask = 1;
   WriteLocalApicReg (XAPIC_LVT_LINT0_OFFSET, LvtLint.Uint32);
 
-  LvtLint.Uint32 = ReadLocalApicReg (XAPIC_LVT_LINT1_OFFSET);
+  LvtLint.Uint32    = ReadLocalApicReg (XAPIC_LVT_LINT1_OFFSET);
   LvtLint.Bits.Mask = 1;
   WriteLocalApicReg (XAPIC_LVT_LINT1_OFFSET, LvtLint.Uint32);
 }
@@ -739,15 +714,15 @@ GetApicTimerCurrentCount (
 VOID
 EFIAPI
 InitializeApicTimer (
-  IN UINTN   DivideValue,
-  IN UINT32  InitCount,
-  IN BOOLEAN PeriodicMode,
-  IN UINT8   Vector
+  IN UINTN    DivideValue,
+  IN UINT32   InitCount,
+  IN BOOLEAN  PeriodicMode,
+  IN UINT8    Vector
   )
 {
-  LOCAL_APIC_DCR       Dcr;
-  LOCAL_APIC_LVT_TIMER LvtTimer;
-  UINT32               Divisor;
+  LOCAL_APIC_DCR        Dcr;
+  LOCAL_APIC_LVT_TIMER  LvtTimer;
+  UINT32                Divisor;
 
   //
   // Ensure local APIC is in software-enabled state.
@@ -761,10 +736,10 @@ InitializeApicTimer (
 
   if (DivideValue != 0) {
     ASSERT (DivideValue <= 128);
-    ASSERT (DivideValue == GetPowerOfTwo32((UINT32)DivideValue));
+    ASSERT (DivideValue == GetPowerOfTwo32 ((UINT32)DivideValue));
     Divisor = (UINT32)((HighBitSet32 ((UINT32)DivideValue) - 1) & 0x7);
 
-    Dcr.Uint32 = ReadLocalApicReg (XAPIC_TIMER_DIVIDE_CONFIGURATION_OFFSET);
+    Dcr.Uint32            = ReadLocalApicReg (XAPIC_TIMER_DIVIDE_CONFIGURATION_OFFSET);
     Dcr.Bits.DivideValue1 = (Divisor & 0x3);
     Dcr.Bits.DivideValue2 = (Divisor >> 2);
     WriteLocalApicReg (XAPIC_TIMER_DIVIDE_CONFIGURATION_OFFSET, Dcr.Uint32);
@@ -779,7 +754,8 @@ InitializeApicTimer (
   } else {
     LvtTimer.Bits.TimerMode = 0;
   }
-  LvtTimer.Bits.Mask = 0;
+
+  LvtTimer.Bits.Mask   = 0;
   LvtTimer.Bits.Vector = Vector;
   WriteLocalApicReg (XAPIC_LVT_TIMER_OFFSET, LvtTimer.Uint32);
 }
@@ -801,25 +777,25 @@ GetApicTimerState (
   OUT UINT8    *Vector  OPTIONAL
   )
 {
-  UINT32 Divisor;
-  LOCAL_APIC_DCR Dcr;
-  LOCAL_APIC_LVT_TIMER LvtTimer;
+  UINT32                Divisor;
+  LOCAL_APIC_DCR        Dcr;
+  LOCAL_APIC_LVT_TIMER  LvtTimer;
 
   //
   // Check the APIC Software Enable/Disable bit (bit 8) in Spurious-Interrupt
   // Vector Register.
   // This bit will be 1, if local APIC is software enabled.
   //
-  ASSERT ((ReadLocalApicReg(XAPIC_SPURIOUS_VECTOR_OFFSET) & BIT8) != 0);
+  ASSERT ((ReadLocalApicReg (XAPIC_SPURIOUS_VECTOR_OFFSET) & BIT8) != 0);
 
   if (DivideValue != NULL) {
-    Dcr.Uint32 = ReadLocalApicReg (XAPIC_TIMER_DIVIDE_CONFIGURATION_OFFSET);
-    Divisor = Dcr.Bits.DivideValue1 | (Dcr.Bits.DivideValue2 << 2);
-    Divisor = (Divisor + 1) & 0x7;
+    Dcr.Uint32   = ReadLocalApicReg (XAPIC_TIMER_DIVIDE_CONFIGURATION_OFFSET);
+    Divisor      = Dcr.Bits.DivideValue1 | (Dcr.Bits.DivideValue2 << 2);
+    Divisor      = (Divisor + 1) & 0x7;
     *DivideValue = ((UINTN)1) << Divisor;
   }
 
-  if (PeriodicMode != NULL || Vector != NULL) {
+  if ((PeriodicMode != NULL) || (Vector != NULL)) {
     LvtTimer.Uint32 = ReadLocalApicReg (XAPIC_LVT_TIMER_OFFSET);
     if (PeriodicMode != NULL) {
       if (LvtTimer.Bits.TimerMode == 1) {
@@ -828,8 +804,9 @@ GetApicTimerState (
         *PeriodicMode = FALSE;
       }
     }
+
     if (Vector != NULL) {
-      *Vector = (UINT8) LvtTimer.Bits.Vector;
+      *Vector = (UINT8)LvtTimer.Bits.Vector;
     }
   }
 }
@@ -843,9 +820,9 @@ EnableApicTimerInterrupt (
   VOID
   )
 {
-  LOCAL_APIC_LVT_TIMER LvtTimer;
+  LOCAL_APIC_LVT_TIMER  LvtTimer;
 
-  LvtTimer.Uint32 = ReadLocalApicReg (XAPIC_LVT_TIMER_OFFSET);
+  LvtTimer.Uint32    = ReadLocalApicReg (XAPIC_LVT_TIMER_OFFSET);
   LvtTimer.Bits.Mask = 0;
   WriteLocalApicReg (XAPIC_LVT_TIMER_OFFSET, LvtTimer.Uint32);
 }
@@ -859,9 +836,9 @@ DisableApicTimerInterrupt (
   VOID
   )
 {
-  LOCAL_APIC_LVT_TIMER LvtTimer;
+  LOCAL_APIC_LVT_TIMER  LvtTimer;
 
-  LvtTimer.Uint32 = ReadLocalApicReg (XAPIC_LVT_TIMER_OFFSET);
+  LvtTimer.Uint32    = ReadLocalApicReg (XAPIC_LVT_TIMER_OFFSET);
   LvtTimer.Bits.Mask = 1;
   WriteLocalApicReg (XAPIC_LVT_TIMER_OFFSET, LvtTimer.Uint32);
 }
@@ -878,7 +855,7 @@ GetApicTimerInterruptState (
   VOID
   )
 {
-  LOCAL_APIC_LVT_TIMER LvtTimer;
+  LOCAL_APIC_LVT_TIMER  LvtTimer;
 
   LvtTimer.Uint32 = ReadLocalApicReg (XAPIC_LVT_TIMER_OFFSET);
   return (BOOLEAN)(LvtTimer.Bits.Mask == 0);
@@ -971,6 +948,7 @@ GetApicMsiValue (
       MsiData.Bits.Level = 1;
     }
   }
+
   return MsiData.Uint64;
 }
 
@@ -1022,12 +1000,15 @@ GetProcessorLocationByApicId (
     if (Thread != NULL) {
       *Thread = 0;
     }
+
     if (Core != NULL) {
       *Core = 0;
     }
+
     if (Package != NULL) {
       *Package = 0;
     }
+
     return;
   }
 
@@ -1035,7 +1016,7 @@ GetProcessorLocationByApicId (
   // Assume three-level mapping of APIC ID: Package|Core|Thread.
   //
   ThreadBits = 0;
-  CoreBits = 0;
+  CoreBits   = 0;
 
   //
   // Get max index of CPUID
@@ -1049,7 +1030,7 @@ GetProcessorLocationByApicId (
   //
   TopologyLeafSupported = FALSE;
   if (MaxStandardCpuIdIndex >= CPUID_EXTENDED_TOPOLOGY) {
-    AsmCpuidEx(
+    AsmCpuidEx (
       CPUID_EXTENDED_TOPOLOGY,
       0,
       &ExtendedTopologyEax.Uint32,
@@ -1092,6 +1073,7 @@ GetProcessorLocationByApicId (
           CoreBits = ExtendedTopologyEax.Bits.ApicIdShift - ThreadBits;
           break;
         }
+
         SubIndex++;
       } while (LevelType != CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_INVALID);
     }
@@ -1112,7 +1094,7 @@ GetProcessorLocationByApicId (
     //
     // Check for topology extensions on AMD processor
     //
-    if (StandardSignatureIsAuthenticAMD()) {
+    if (StandardSignatureIsAuthenticAMD ()) {
       if (MaxExtendedCpuIdIndex >= CPUID_AMD_PROCESSOR_TOPOLOGY) {
         AsmCpuid (CPUID_EXTENDED_CPU_SIG, NULL, NULL, &AmdExtendedCpuSigEcx.Uint32, NULL);
         if (AmdExtendedCpuSigEcx.Bits.TopologyExtensions != 0) {
@@ -1129,8 +1111,7 @@ GetProcessorLocationByApicId (
           MaxCoresPerPackage = MaxLogicProcessorsPerPackage / (AmdProcessorTopologyEbx.Bits.ThreadsPerCore + 1);
         }
       }
-    }
-    else {
+    } else {
       //
       // Extract core count based on CACHE information
       //
@@ -1142,17 +1123,147 @@ GetProcessorLocationByApicId (
       }
     }
 
-    ThreadBits = (UINTN)(HighBitSet32(MaxLogicProcessorsPerPackage / MaxCoresPerPackage - 1) + 1);
-    CoreBits = (UINTN)(HighBitSet32(MaxCoresPerPackage - 1) + 1);
+    ThreadBits = (UINTN)(HighBitSet32 (MaxLogicProcessorsPerPackage / MaxCoresPerPackage - 1) + 1);
+    CoreBits   = (UINTN)(HighBitSet32 (MaxCoresPerPackage - 1) + 1);
   }
 
   if (Thread != NULL) {
     *Thread = InitialApicId & ((1 << ThreadBits) - 1);
   }
+
   if (Core != NULL) {
     *Core = (InitialApicId >> ThreadBits) & ((1 << CoreBits) - 1);
   }
+
   if (Package != NULL) {
     *Package = (InitialApicId >> (ThreadBits + CoreBits));
   }
 }
+
+/**
+  Get Package ID/Die ID/Tile ID/Module ID/Core ID/Thread ID of a processor.
+
+  The algorithm assumes the target system has symmetry across physical
+  package boundaries with respect to the number of threads per core, number of
+  cores per module, number of modules per tile, number of tiles per die, number
+  of dies per package.
+
+  @param[in]   InitialApicId Initial APIC ID of the target logical processor.
+  @param[out]  Package       Returns the processor package ID.
+  @param[out]  Die           Returns the processor die ID.
+  @param[out]  Tile          Returns the processor tile ID.
+  @param[out]  Module        Returns the processor module ID.
+  @param[out]  Core          Returns the processor core ID.
+  @param[out]  Thread        Returns the processor thread ID.
+**/
+VOID
+EFIAPI
+GetProcessorLocation2ByApicId (
+  IN  UINT32  InitialApicId,
+  OUT UINT32  *Package  OPTIONAL,
+  OUT UINT32  *Die      OPTIONAL,
+  OUT UINT32  *Tile     OPTIONAL,
+  OUT UINT32  *Module   OPTIONAL,
+  OUT UINT32  *Core     OPTIONAL,
+  OUT UINT32  *Thread   OPTIONAL
+  )
+{
+  CPUID_EXTENDED_TOPOLOGY_EAX  ExtendedTopologyEax;
+  CPUID_EXTENDED_TOPOLOGY_ECX  ExtendedTopologyEcx;
+  UINT32                       MaxStandardCpuIdIndex;
+  UINT32                       Index;
+  UINTN                        LevelType;
+  UINT32                       Bits[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_DIE + 2];
+  UINT32                       *Location[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_DIE + 2];
+
+  for (LevelType = 0; LevelType < ARRAY_SIZE (Bits); LevelType++) {
+    Bits[LevelType] = 0;
+  }
+
+  //
+  // Get max index of CPUID
+  //
+  AsmCpuid (CPUID_SIGNATURE, &MaxStandardCpuIdIndex, NULL, NULL, NULL);
+  if (MaxStandardCpuIdIndex < CPUID_V2_EXTENDED_TOPOLOGY) {
+    if (Die != NULL) {
+      *Die = 0;
+    }
+
+    if (Tile != NULL) {
+      *Tile = 0;
+    }
+
+    if (Module != NULL) {
+      *Module = 0;
+    }
+
+    GetProcessorLocationByApicId (InitialApicId, Package, Core, Thread);
+    return;
+  }
+
+  //
+  // If the V2 extended topology enumeration leaf is available, it
+  // is the preferred mechanism for enumerating topology.
+  //
+  for (Index = 0; ; Index++) {
+    AsmCpuidEx (
+      CPUID_V2_EXTENDED_TOPOLOGY,
+      Index,
+      &ExtendedTopologyEax.Uint32,
+      NULL,
+      &ExtendedTopologyEcx.Uint32,
+      NULL
+      );
+
+    LevelType = ExtendedTopologyEcx.Bits.LevelType;
+
+    //
+    // first level reported should be SMT.
+    //
+    ASSERT ((Index != 0) || (LevelType == CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_SMT));
+    if (LevelType == CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_INVALID) {
+      break;
+    }
+
+    ASSERT (LevelType < ARRAY_SIZE (Bits));
+    Bits[LevelType] = ExtendedTopologyEax.Bits.ApicIdShift;
+  }
+
+  for (LevelType = CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_CORE; LevelType < ARRAY_SIZE (Bits); LevelType++) {
+    //
+    // If there are more levels between level-1 (low-level) and level-2 (high-level), the unknown levels will be ignored
+    // and treated as an extension of the last known level (i.e., level-1 in this case).
+    //
+    if (Bits[LevelType] == 0) {
+      Bits[LevelType] = Bits[LevelType - 1];
+    }
+  }
+
+  Location[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_DIE + 1] = Package;
+  Location[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_DIE]     = Die;
+  Location[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_TILE]    = Tile;
+  Location[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_MODULE]  = Module;
+  Location[CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_CORE]       = Core;
+  Location[CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_SMT]        = Thread;
+
+  Bits[CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_DIE + 1] = 32;
+
+  for ( LevelType = CPUID_EXTENDED_TOPOLOGY_LEVEL_TYPE_SMT
+        ; LevelType <= CPUID_V2_EXTENDED_TOPOLOGY_LEVEL_TYPE_DIE + 1
+        ; LevelType++
+        )
+  {
+    if (Location[LevelType] != NULL) {
+      //
+      // Bits[i] holds the number of bits to shift right on x2APIC ID to get a unique
+      // topology ID of the next level type.
+      //
+      *Location[LevelType] = InitialApicId >> Bits[LevelType - 1];
+
+      //
+      // Bits[i] - Bits[i-1] holds the number of bits for the next ONE level type.
+      //
+      *Location[LevelType] &= (1 << (Bits[LevelType] - Bits[LevelType - 1])) - 1;
+    }
+  }
+}
